------------------------------------------------------------------------------
-- user_logic.vhd - entity/architecture pair
------------------------------------------------------------------------------
--
-- ***************************************************************************
-- ** Copyright (c) 1995-2006 Xilinx, Inc.  All rights reserved.            **
-- **                                                                       **
-- ** Xilinx, Inc.                                                          **
-- ** XILINX IS PROVIDING THIS DESIGN, CODE, OR INFORMATION "AS IS"         **
-- ** AS A COURTESY TO YOU, SOLELY FOR USE IN DEVELOPING PROGRAMS AND       **
-- ** SOLUTIONS FOR XILINX DEVICES.  BY PROVIDING THIS DESIGN, CODE,        **
-- ** OR INFORMATION AS ONE POSSIBLE IMPLEMENTATION OF THIS FEATURE,        **
-- ** APPLICATION OR STANDARD, XILINX IS MAKING NO REPRESENTATION           **
-- ** THAT THIS IMPLEMENTATION IS FREE FROM ANY CLAIMS OF INFRINGEMENT,     **
-- ** AND YOU ARE RESPONSIBLE FOR OBTAINING ANY RIGHTS YOU MAY REQUIRE      **
-- ** FOR YOUR IMPLEMENTATION.  XILINX EXPRESSLY DISCLAIMS ANY              **
-- ** WARRANTY WHATSOEVER WITH RESPECT TO THE ADEQUACY OF THE               **
-- ** IMPLEMENTATION, INCLUDING BUT NOT LIMITED TO ANY WARRANTIES OR        **
-- ** REPRESENTATIONS THAT THIS IMPLEMENTATION IS FREE FROM CLAIMS OF       **
-- ** INFRINGEMENT, IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS       **
-- ** FOR A PARTICULAR PURPOSE.                                             **
-- **                                                                       **
-- ***************************************************************************
--
------------------------------------------------------------------------------
-- Filename:          user_logic.vhd
-- Version:           1.00.a
-- Description:       User logic.
-- Date:              Thu Feb  8 12:34:55 2007 (by Create and Import Peripheral Wizard)
-- VHDL Standard:     VHDL'93
------------------------------------------------------------------------------
-- Naming Conventions:
--   active low signals:                    "*_n"
--   clock signals:                         "clk", "clk_div#", "clk_#x"
--   reset signals:                         "rst", "rst_n"
--   generics:                              "C_*"
--   user defined types:                    "*_TYPE"
--   state machine next state:              "*_ns"
--   state machine current state:           "*_cs"
--   combinatorial signals:                 "*_com"
--   pipelined or register delay signals:   "*_d#"
--   counter signals:                       "*cnt*"
--   clock enable signals:                  "*_ce"
--   internal version of output port:       "*_i"
--   device pins:                           "*_pin"
--   ports:                                 "- Names begin with Uppercase"
--   processes:                             "*_PROCESS"
--   component instantiations:              "<ENTITY_>I_<#|FUNC>"
------------------------------------------------------------------------------

-- DO NOT EDIT BELOW THIS LINE --------------------
library ieee;
use ieee.std_logic_1164.all;
use ieee.std_logic_arith.all;
use ieee.std_logic_unsigned.all;

library proc_common_v2_00_a;
use proc_common_v2_00_a.proc_common_pkg.all;
-- DO NOT EDIT ABOVE THIS LINE --------------------

--USER libraries added here

------------------------------------------------------------------------------
-- Entity section
------------------------------------------------------------------------------
-- Definition of Generics:
--   C_AWIDTH                     -- User logic address bus width
--   C_DWIDTH                     -- User logic data bus width
--   C_NUM_CE                     -- User logic chip enable bus width
--
-- Definition of Ports:
--   Bus2IP_Clk                   -- Bus to IP clock
--   Bus2IP_Reset                 -- Bus to IP reset
--   Bus2IP_Addr                  -- Bus to IP address bus
--   Bus2IP_Data                  -- Bus to IP data bus for user logic
--   Bus2IP_BE                    -- Bus to IP byte enables for user logic
--   Bus2IP_RNW                   -- Bus to IP read/not write
--   Bus2IP_RdCE                  -- Bus to IP read chip enable for user logic
--   Bus2IP_WrCE                  -- Bus to IP write chip enable for user logic
--   IP2Bus_Data                  -- IP to Bus data bus for user logic
--   IP2Bus_Ack                   -- IP to Bus acknowledgement
--   IP2Bus_Retry                 -- IP to Bus retry response
--   IP2Bus_Error                 -- IP to Bus error response
--   IP2Bus_ToutSup               -- IP to Bus timeout suppress
------------------------------------------------------------------------------

entity user_logic is
  generic
  (
    -- ADD USER GENERICS BELOW THIS LINE ---------------
    --USER generics added here
    -- ADD USER GENERICS ABOVE THIS LINE ---------------

    -- DO NOT EDIT BELOW THIS LINE ---------------------
    -- Bus protocol parameters, do not add to or delete
    C_AWIDTH                       : integer              := 32;
    C_DWIDTH                       : integer              := 32;
    C_NUM_CE                       : integer              := 2
    -- DO NOT EDIT ABOVE THIS LINE ---------------------
  );
  port
  (
    -- ADD USER PORTS BELOW THIS LINE ------------------
      --USER ports added here
	-- The data I send out off the chip
	OMA_DATA_O						: out std_logic_vector(0 to C_DWIDTH-1);
	-- The data I get in from outside the chip.
	OMA_DATA_I						: in std_logic_vector(0 to C_DWIDTH-1) := (others => '0');
	-- If the data on OMA_DATA_* is the data you requested.
	OMA_VALID						: in std_logic := '0';
	-- Which addr to operate on. 
	OMA_ADDRESS						: out std_logic_vector(0 to C_AWIDTH-1);
	-- Read or write. On asserted we read. 
	OMA_RW							: out std_logic;
	-- If there is a request pending. 
	OMA_ACTIVE						: out std_logic;
	-- Leds debug
	LEDS_DEBUG						: out std_logic_vector( 0 to 15 );
	OMA_BE							: out std_logic_vector(0 to C_DWIDTH/8-1);
	
    -- ADD USER PORTS ABOVE THIS LINE ------------------

    -- DO NOT EDIT BELOW THIS LINE ---------------------
    -- Bus protocol ports, do not add to or delete
    Bus2IP_Clk                     : in  std_logic;
    Bus2IP_Reset                   : in  std_logic;
    Bus2IP_Addr                    : in  std_logic_vector(0 to C_AWIDTH-1);
    Bus2IP_Data                    : in  std_logic_vector(0 to C_DWIDTH-1);
    Bus2IP_BE                      : in  std_logic_vector(0 to C_DWIDTH/8-1);
    Bus2IP_RNW                     : in  std_logic;
    Bus2IP_RdCE                    : in  std_logic_vector(0 to C_NUM_CE-1);
    Bus2IP_WrCE                    : in  std_logic_vector(0 to C_NUM_CE-1);
    IP2Bus_Data                    : out std_logic_vector(0 to C_DWIDTH-1);
    IP2Bus_Ack                     : out std_logic;
    IP2Bus_Retry                   : out std_logic;
    IP2Bus_Error                   : out std_logic;
    IP2Bus_ToutSup                 : out std_logic
    -- DO NOT EDIT ABOVE THIS LINE ---------------------
  );
end entity user_logic;

------------------------------------------------------------------------------
-- Architecture section
------------------------------------------------------------------------------

architecture IMP of user_logic is
 type STATE is ( IDLE, READING, WRITING, RCOMP, WCOMP ); 

 signal writeEnabled 	: std_logic := '0';
 signal readEnabled		: std_logic := '0';
 signal clock				: std_logic; 
 signal iState				: STATE := IDLE;
 signal leds				: std_logic_vector(0 to 15) := (others => '1');
 
 signal address			: std_logic_vector(0 to C_AWIDTH-1)	:= (others =>'1'); 
 signal data_out			: std_logic_vector(0 to C_AWIDTH-1) := (others =>'1');

begin
	-- My own signals. 
	writeEnabled 	<= (Bus2IP_WrCE(0) or Bus2IP_WrCE(1) ) and not Bus2IP_RNW ;
	readEnabled		<= (Bus2IP_RdCE(0) or Bus2IP_RdCE(1) ) and Bus2IP_RNW ;

	clock				<= Bus2IP_Clk;
	
	-- Let some signals out independently of anything else.
	--OMA_ADDRESS 	<= Bus2IP_Addr;
	--OMA_DATA_O 		<= Bus2IP_Data;
	OMA_ADDRESS 	<= address;
	OMA_DATA_O 		<= data_out;
	OMA_BE			<= Bus2IP_BE;
	
	LEDS_DEBUG		<= leds; 
	
	-- Everything on time.
	INN: process(clock)
	begin
		if rising_edge(clock) then 
			-- Default sending out 0x00 on the databus
			-- to the core. 
			IP2Bus_Data <= (others => '0');
			IP2Bus_Ack <= '0';
			
			case iState is 
				when IDLE =>
					if readEnabled = '1' then
						OMA_ACTIVE	<= '1';
						OMA_RW 		<= '1';
						IP2Bus_Data	<= OMA_DATA_I;
						address		<= Bus2IP_Addr;
						iState <= READING; 
					elsif writeEnabled = '1' then
						OMA_ACTIVE	<= '1';
						OMA_RW 		<= '0';
						iState 		<= WRITING;
						address		<= Bus2IP_Addr;
						data_out		<= Bus2IP_Data;
					end if;
					
				when READING =>
				-- We will use more than 16 cycles. 
					IP2Bus_ToutSup     <= '1';
					IP2Bus_Data <= OMA_DATA_I;
					
					-- Check for doneness.
					if OMA_VALID = '1' then
						iState <= RCOMP;
						OMA_ACTIVE <= '0';
						IP2Bus_ToutSup		<= '0';
						IP2Bus_Ack			<= '1';
						leds  				<= OMA_DATA_I(0 to 15);
					end if;
							
				when WRITING =>
				-- We will use more than 16 cycles. 
					IP2Bus_ToutSup     <= '1';				
				-- Check for doneness.
					if OMA_VALID = '1' then
						iState			<= WCOMP;
						OMA_ACTIVE		<= '0';
						IP2Bus_ToutSup	<= '0';
						IP2Bus_Ack		<= '1';
					end if;
				
				when others =>
					OMA_ACTIVE 	<= '0';
					IP2Bus_Ack	<= '0';
					iState <= IDLE;
			end case; 
			
		end if;
	end process; 

  IP2Bus_Error       <= '0';
  IP2Bus_Retry       <= '0';

end IMP;
