----------------------------------------------------------------------------------
-- Company: 
-- Engineer: 
-- 
-- Create Date:    10:28:34 04/13/2007 
-- Design Name: 
-- Module Name:    arbiter - Behavioral 
-- Project Name: 
-- Target Devices: 
-- Tool versions: 
-- Description: 
--
-- Dependencies: 
--
-- Revision: 
-- Revision 0.01 - File Created
-- Additional Comments: 
--
----------------------------------------------------------------------------------
library IEEE;
use IEEE.STD_LOGIC_1164.ALL;
use IEEE.STD_LOGIC_ARITH.ALL;
use IEEE.STD_LOGIC_UNSIGNED.ALL;

---- Uncomment the following library declaration if instantiating
---- any Xilinx primitives in this code.
--library UNISIM;
--use UNISIM.VComponents.all;

library WORK;
use WORK.coreStuff.ALL;

entity arbiter is
	port (
		CLOCK				: IN std_logic;
		RESET				: IN std_logic;

		IN_OMA_VALID		: OUT coreBit;
		IN_OMA_DATA_I		: OUT coreVector;
		IN_OMA_DATA_O		: IN  coreVector;
		IN_OMA_ADDRESS		: IN  coreVector;
		IN_OMA_BE			: IN  coreBe;
		IN_OMA_RW			: IN  coreBit;
		IN_OMA_ACTIVE		: IN  coreBit;
		
		OUT_OMA_VALID		: IN  std_logic;
		OUT_OMA_DATA_I		: IN  std_logic_vector(0 to 31);
		OUT_OMA_DATA_O		: OUT std_logic_vector(0 to 31);
		OUT_OMA_ADDRESS		: OUT std_logic_vector(0 to 31);
		OUT_OMA_BE			: OUT std_logic_vector(0 to 3);
		OUT_OMA_RW			: OUT std_logic;
		OUT_OMA_ACTIVE		: OUT std_logic
	);
end arbiter;

architecture Behavioral of arbiter is
	signal active			: std_logic := '0';
	shared variable currentActive	: natural := 0;
begin

	f: process is
	begin
		IN_OMA_VALID	<= (others => '0');
		IN_OMA_VALID(currentActive)		<= OUT_OMA_VALID;	
		IN_OMA_DATA_I(currentActive)		<= OUT_OMA_DATA_I;
		OUT_OMA_DATA_O		<= IN_OMA_DATA_O(currentActive);
		OUT_OMA_ADDRESS		<= IN_OMA_ADDRESS(currentActive);
		OUT_OMA_BE			<= IN_OMA_BE(currentActive);
		OUT_OMA_RW			<= IN_OMA_RW(currentActive);
		OUT_OMA_ACTIVE		<= IN_OMA_ACTIVE(currentActive);			
	end process;

	switcher: process(CLOCK, IN_OMA_ACTIVE, OUT_OMA_VALID ) is
	begin 
		if rising_edge(CLOCK) then 
			-- If someone already are sending and receiving
			-- data, we'll wait for the ack to get back..
			if active = '1' then 
				-- Set no active on VALID data. 
				if OUT_OMA_VALID = '1' then 
					active 			<= '0';
				end if;
				
			
			else
				for I in 0 to numCores - 1 loop 
					if IN_OMA_ACTIVE((currentActive + I) mod numCores) = '1' then 
						-- Find the active one.
						currentActive 		:= (currentActive + I) mod numCores; 
						active				<=  '1';
						exit; 
					end if;
				end loop; 
			end if;
		end if;
	end process;

end Behavioral;	

