-------------------------------------------------------------------------------
-- system.vhd
-------------------------------------------------------------------------------
library IEEE;
use IEEE.STD_LOGIC_1164.ALL;

library UNISIM;
use UNISIM.VCOMPONENTS.ALL;

entity system is
  port (
    sys_clk_pin : in std_logic;
    sys_rst_pin : in std_logic;
    opb_external_memory_0_OMA_DATA_O_pin : out std_logic_vector(0 to 31);
    opb_external_memory_0_OMA_DATA_I_pin : in std_logic_vector(0 to 31);
    opb_external_memory_0_OMA_VALID_pin : in std_logic;
    opb_external_memory_0_OMA_ADDRESS_pin : out std_logic_vector(0 to 31);
    opb_external_memory_0_OMA_RW_pin : out std_logic;
    opb_external_memory_0_OMA_ACTIVE_pin : out std_logic;
    opb_external_memory_0_LEDS_DEBUG_pin : out std_logic_vector(0 to 15);
    opb_external_memory_0_OMA_BE_pin : out std_logic_vector(0 to 3)
  );
end system;

architecture STRUCTURE of system is

  attribute box_type : STRING;

  component microblaze_0_wrapper is
    port (
      CLK : in std_logic;
      RESET : in std_logic;
      INTERRUPT : in std_logic;
      DEBUG_RST : in std_logic;
      EXT_BRK : in std_logic;
      EXT_NM_BRK : in std_logic;
      DBG_STOP : in std_logic;
      INSTR : in std_logic_vector(0 to 31);
      I_ADDRTAG : out std_logic_vector(0 to 3);
      IREADY : in std_logic;
      IWAIT : in std_logic;
      INSTR_ADDR : out std_logic_vector(0 to 31);
      IFETCH : out std_logic;
      I_AS : out std_logic;
      DATA_READ : in std_logic_vector(0 to 31);
      DREADY : in std_logic;
      DWAIT : in std_logic;
      DATA_WRITE : out std_logic_vector(0 to 31);
      DATA_ADDR : out std_logic_vector(0 to 31);
      D_ADDRTAG : out std_logic_vector(0 to 3);
      D_AS : out std_logic;
      READ_STROBE : out std_logic;
      WRITE_STROBE : out std_logic;
      BYTE_ENABLE : out std_logic_vector(0 to 3);
      DM_ABUS : out std_logic_vector(0 to 31);
      DM_BE : out std_logic_vector(0 to 3);
      DM_BUSLOCK : out std_logic;
      DM_DBUS : out std_logic_vector(0 to 31);
      DM_REQUEST : out std_logic;
      DM_RNW : out std_logic;
      DM_SELECT : out std_logic;
      DM_SEQADDR : out std_logic;
      DOPB_DBUS : in std_logic_vector(0 to 31);
      DOPB_ERRACK : in std_logic;
      DOPB_MGRANT : in std_logic;
      DOPB_RETRY : in std_logic;
      DOPB_TIMEOUT : in std_logic;
      DOPB_XFERACK : in std_logic;
      IM_ABUS : out std_logic_vector(0 to 31);
      IM_BE : out std_logic_vector(0 to 3);
      IM_BUSLOCK : out std_logic;
      IM_DBUS : out std_logic_vector(0 to 31);
      IM_REQUEST : out std_logic;
      IM_RNW : out std_logic;
      IM_SELECT : out std_logic;
      IM_SEQADDR : out std_logic;
      IOPB_DBUS : in std_logic_vector(0 to 31);
      IOPB_ERRACK : in std_logic;
      IOPB_MGRANT : in std_logic;
      IOPB_RETRY : in std_logic;
      IOPB_TIMEOUT : in std_logic;
      IOPB_XFERACK : in std_logic;
      DBG_CLK : in std_logic;
      DBG_TDI : in std_logic;
      DBG_TDO : out std_logic;
      DBG_REG_EN : in std_logic_vector(0 to 4);
      DBG_CAPTURE : in std_logic;
      DBG_UPDATE : in std_logic;
      VALID_INSTR : out std_logic;
      PC_EX : out std_logic_vector(0 to 31);
      REG_WRITE : out std_logic;
      REG_ADDR : out std_logic_vector(0 to 4);
      MSR_REG : out std_logic_vector(0 to 9);
      NEW_REG_VALUE : out std_logic_vector(0 to 31);
      PIPE_RUNNING : out std_logic;
      INTERRUPT_TAKEN : out std_logic;
      JUMP_TAKEN : out std_logic;
      PREFETCH_ADDR : out std_logic_vector(0 to 3);
      MB_Halted : out std_logic;
      Trace_Branch_Instr : out std_logic;
      Trace_Delay_Slot : out std_logic;
      Trace_Data_Address : out std_logic_vector(0 to 31);
      Trace_AS : out std_logic;
      Trace_Data_Read : out std_logic;
      Trace_Data_Write : out std_logic;
      Trace_DCache_Req : out std_logic;
      Trace_DCache_Hit : out std_logic;
      Trace_ICache_Req : out std_logic;
      Trace_ICache_Hit : out std_logic;
      Trace_Instr_EX : out std_logic_vector(0 to 31);
      FSL0_S_CLK : out std_logic;
      FSL0_S_READ : out std_logic;
      FSL0_S_DATA : in std_logic_vector(0 to 31);
      FSL0_S_CONTROL : in std_logic;
      FSL0_S_EXISTS : in std_logic;
      FSL0_M_CLK : out std_logic;
      FSL0_M_WRITE : out std_logic;
      FSL0_M_DATA : out std_logic_vector(0 to 31);
      FSL0_M_CONTROL : out std_logic;
      FSL0_M_FULL : in std_logic;
      FSL1_S_CLK : out std_logic;
      FSL1_S_READ : out std_logic;
      FSL1_S_DATA : in std_logic_vector(0 to 31);
      FSL1_S_CONTROL : in std_logic;
      FSL1_S_EXISTS : in std_logic;
      FSL1_M_CLK : out std_logic;
      FSL1_M_WRITE : out std_logic;
      FSL1_M_DATA : out std_logic_vector(0 to 31);
      FSL1_M_CONTROL : out std_logic;
      FSL1_M_FULL : in std_logic;
      FSL2_S_CLK : out std_logic;
      FSL2_S_READ : out std_logic;
      FSL2_S_DATA : in std_logic_vector(0 to 31);
      FSL2_S_CONTROL : in std_logic;
      FSL2_S_EXISTS : in std_logic;
      FSL2_M_CLK : out std_logic;
      FSL2_M_WRITE : out std_logic;
      FSL2_M_DATA : out std_logic_vector(0 to 31);
      FSL2_M_CONTROL : out std_logic;
      FSL2_M_FULL : in std_logic;
      FSL3_S_CLK : out std_logic;
      FSL3_S_READ : out std_logic;
      FSL3_S_DATA : in std_logic_vector(0 to 31);
      FSL3_S_CONTROL : in std_logic;
      FSL3_S_EXISTS : in std_logic;
      FSL3_M_CLK : out std_logic;
      FSL3_M_WRITE : out std_logic;
      FSL3_M_DATA : out std_logic_vector(0 to 31);
      FSL3_M_CONTROL : out std_logic;
      FSL3_M_FULL : in std_logic;
      FSL4_S_CLK : out std_logic;
      FSL4_S_READ : out std_logic;
      FSL4_S_DATA : in std_logic_vector(0 to 31);
      FSL4_S_CONTROL : in std_logic;
      FSL4_S_EXISTS : in std_logic;
      FSL4_M_CLK : out std_logic;
      FSL4_M_WRITE : out std_logic;
      FSL4_M_DATA : out std_logic_vector(0 to 31);
      FSL4_M_CONTROL : out std_logic;
      FSL4_M_FULL : in std_logic;
      FSL5_S_CLK : out std_logic;
      FSL5_S_READ : out std_logic;
      FSL5_S_DATA : in std_logic_vector(0 to 31);
      FSL5_S_CONTROL : in std_logic;
      FSL5_S_EXISTS : in std_logic;
      FSL5_M_CLK : out std_logic;
      FSL5_M_WRITE : out std_logic;
      FSL5_M_DATA : out std_logic_vector(0 to 31);
      FSL5_M_CONTROL : out std_logic;
      FSL5_M_FULL : in std_logic;
      FSL6_S_CLK : out std_logic;
      FSL6_S_READ : out std_logic;
      FSL6_S_DATA : in std_logic_vector(0 to 31);
      FSL6_S_CONTROL : in std_logic;
      FSL6_S_EXISTS : in std_logic;
      FSL6_M_CLK : out std_logic;
      FSL6_M_WRITE : out std_logic;
      FSL6_M_DATA : out std_logic_vector(0 to 31);
      FSL6_M_CONTROL : out std_logic;
      FSL6_M_FULL : in std_logic;
      FSL7_S_CLK : out std_logic;
      FSL7_S_READ : out std_logic;
      FSL7_S_DATA : in std_logic_vector(0 to 31);
      FSL7_S_CONTROL : in std_logic;
      FSL7_S_EXISTS : in std_logic;
      FSL7_M_CLK : out std_logic;
      FSL7_M_WRITE : out std_logic;
      FSL7_M_DATA : out std_logic_vector(0 to 31);
      FSL7_M_CONTROL : out std_logic;
      FSL7_M_FULL : in std_logic;
      ICACHE_FSL_IN_CLK : out std_logic;
      ICACHE_FSL_IN_READ : out std_logic;
      ICACHE_FSL_IN_DATA : in std_logic_vector(0 to 31);
      ICACHE_FSL_IN_CONTROL : in std_logic;
      ICACHE_FSL_IN_EXISTS : in std_logic;
      ICACHE_FSL_OUT_CLK : out std_logic;
      ICACHE_FSL_OUT_WRITE : out std_logic;
      ICACHE_FSL_OUT_DATA : out std_logic_vector(0 to 31);
      ICACHE_FSL_OUT_CONTROL : out std_logic;
      ICACHE_FSL_OUT_FULL : in std_logic;
      DCACHE_FSL_IN_CLK : out std_logic;
      DCACHE_FSL_IN_READ : out std_logic;
      DCACHE_FSL_IN_DATA : in std_logic_vector(0 to 31);
      DCACHE_FSL_IN_CONTROL : in std_logic;
      DCACHE_FSL_IN_EXISTS : in std_logic;
      DCACHE_FSL_OUT_CLK : out std_logic;
      DCACHE_FSL_OUT_WRITE : out std_logic;
      DCACHE_FSL_OUT_DATA : out std_logic_vector(0 to 31);
      DCACHE_FSL_OUT_CONTROL : out std_logic;
      DCACHE_FSL_OUT_FULL : in std_logic
    );
  end component;

  attribute box_type of microblaze_0_wrapper: component is "black_box";

  component mb_opb_wrapper is
    port (
      OPB_Clk : in std_logic;
      OPB_Rst : out std_logic;
      SYS_Rst : in std_logic;
      Debug_SYS_Rst : in std_logic;
      WDT_Rst : in std_logic;
      M_ABus : in std_logic_vector(0 to 63);
      M_BE : in std_logic_vector(0 to 7);
      M_beXfer : in std_logic_vector(0 to 1);
      M_busLock : in std_logic_vector(0 to 1);
      M_DBus : in std_logic_vector(0 to 63);
      M_DBusEn : in std_logic_vector(0 to 1);
      M_DBusEn32_63 : in std_logic_vector(0 to 1);
      M_dwXfer : in std_logic_vector(0 to 1);
      M_fwXfer : in std_logic_vector(0 to 1);
      M_hwXfer : in std_logic_vector(0 to 1);
      M_request : in std_logic_vector(0 to 1);
      M_RNW : in std_logic_vector(0 to 1);
      M_select : in std_logic_vector(0 to 1);
      M_seqAddr : in std_logic_vector(0 to 1);
      Sl_beAck : in std_logic_vector(0 to 0);
      Sl_DBus : in std_logic_vector(0 to 31);
      Sl_DBusEn : in std_logic_vector(0 to 0);
      Sl_DBusEn32_63 : in std_logic_vector(0 to 0);
      Sl_errAck : in std_logic_vector(0 to 0);
      Sl_dwAck : in std_logic_vector(0 to 0);
      Sl_fwAck : in std_logic_vector(0 to 0);
      Sl_hwAck : in std_logic_vector(0 to 0);
      Sl_retry : in std_logic_vector(0 to 0);
      Sl_toutSup : in std_logic_vector(0 to 0);
      Sl_xferAck : in std_logic_vector(0 to 0);
      OPB_MRequest : out std_logic_vector(0 to 1);
      OPB_ABus : out std_logic_vector(0 to 31);
      OPB_BE : out std_logic_vector(0 to 3);
      OPB_beXfer : out std_logic;
      OPB_beAck : out std_logic;
      OPB_busLock : out std_logic;
      OPB_rdDBus : out std_logic_vector(0 to 31);
      OPB_wrDBus : out std_logic_vector(0 to 31);
      OPB_DBus : out std_logic_vector(0 to 31);
      OPB_errAck : out std_logic;
      OPB_dwAck : out std_logic;
      OPB_dwXfer : out std_logic;
      OPB_fwAck : out std_logic;
      OPB_fwXfer : out std_logic;
      OPB_hwAck : out std_logic;
      OPB_hwXfer : out std_logic;
      OPB_MGrant : out std_logic_vector(0 to 1);
      OPB_pendReq : out std_logic_vector(0 to 1);
      OPB_retry : out std_logic;
      OPB_RNW : out std_logic;
      OPB_select : out std_logic;
      OPB_seqAddr : out std_logic;
      OPB_timeout : out std_logic;
      OPB_toutSup : out std_logic;
      OPB_xferAck : out std_logic
    );
  end component;

  attribute box_type of mb_opb_wrapper: component is "black_box";

  component opb_external_memory_0_wrapper is
    port (
      OPB_Clk : in std_logic;
      OPB_Rst : in std_logic;
      Sl_DBus : out std_logic_vector(0 to 31);
      Sl_errAck : out std_logic;
      Sl_retry : out std_logic;
      Sl_toutSup : out std_logic;
      Sl_xferAck : out std_logic;
      OPB_ABus : in std_logic_vector(0 to 31);
      OPB_BE : in std_logic_vector(0 to 3);
      OPB_DBus : in std_logic_vector(0 to 31);
      OPB_RNW : in std_logic;
      OPB_select : in std_logic;
      OPB_seqAddr : in std_logic;
      OMA_DATA_O : out std_logic_vector(0 to 31);
      OMA_DATA_I : in std_logic_vector(0 to 31);
      OMA_VALID : in std_logic;
      OMA_ADDRESS : out std_logic_vector(0 to 31);
      OMA_RW : out std_logic;
      OMA_ACTIVE : out std_logic;
      LEDS_DEBUG : out std_logic_vector(0 to 15);
      OMA_BE : out std_logic_vector(0 to 3)
    );
  end component;

  attribute box_type of opb_external_memory_0_wrapper: component is "black_box";

  component cpu_identifier_0_wrapper is
    port (
      FSL_Clk : in std_logic;
      FSL_Rst : in std_logic;
      FSL_S_Clk : out std_logic;
      FSL_S_Read : out std_logic;
      FSL_S_Data : in std_logic_vector(0 to 31);
      FSL_S_Control : in std_logic;
      FSL_S_Exists : in std_logic;
      FSL_M_Clk : out std_logic;
      FSL_M_Write : out std_logic;
      FSL_M_Data : out std_logic_vector(0 to 31);
      FSL_M_Control : out std_logic;
      FSL_M_Full : in std_logic
    );
  end component;

  attribute box_type of cpu_identifier_0_wrapper: component is "black_box";

  component fsl_v20_0_wrapper is
    port (
      FSL_Clk : in std_logic;
      SYS_Rst : in std_logic;
      FSL_Rst : out std_logic;
      FSL_M_Clk : in std_logic;
      FSL_M_Data : in std_logic_vector(0 to 31);
      FSL_M_Control : in std_logic;
      FSL_M_Write : in std_logic;
      FSL_M_Full : out std_logic;
      FSL_S_Clk : in std_logic;
      FSL_S_Data : out std_logic_vector(0 to 31);
      FSL_S_Control : out std_logic;
      FSL_S_Read : in std_logic;
      FSL_S_Exists : out std_logic;
      FSL_Full : out std_logic;
      FSL_Has_Data : out std_logic
    );
  end component;

  attribute box_type of fsl_v20_0_wrapper: component is "black_box";

  component bram_block_0_wrapper is
    port (
      BRAM_Rst_A : in std_logic;
      BRAM_Clk_A : in std_logic;
      BRAM_EN_A : in std_logic;
      BRAM_WEN_A : in std_logic_vector(0 to 3);
      BRAM_Addr_A : in std_logic_vector(0 to 31);
      BRAM_Din_A : out std_logic_vector(0 to 31);
      BRAM_Dout_A : in std_logic_vector(0 to 31);
      BRAM_Rst_B : in std_logic;
      BRAM_Clk_B : in std_logic;
      BRAM_EN_B : in std_logic;
      BRAM_WEN_B : in std_logic_vector(0 to 3);
      BRAM_Addr_B : in std_logic_vector(0 to 31);
      BRAM_Din_B : out std_logic_vector(0 to 31);
      BRAM_Dout_B : in std_logic_vector(0 to 31)
    );
  end component;

  attribute box_type of bram_block_0_wrapper: component is "black_box";

  component lmb_bram_if_cntlr_0_wrapper is
    port (
      LMB_Clk : in std_logic;
      LMB_Rst : in std_logic;
      LMB_ABus : in std_logic_vector(0 to 31);
      LMB_WriteDBus : in std_logic_vector(0 to 31);
      LMB_AddrStrobe : in std_logic;
      LMB_ReadStrobe : in std_logic;
      LMB_WriteStrobe : in std_logic;
      LMB_BE : in std_logic_vector(0 to 3);
      Sl_DBus : out std_logic_vector(0 to 31);
      Sl_Ready : out std_logic;
      BRAM_Rst_A : out std_logic;
      BRAM_Clk_A : out std_logic;
      BRAM_EN_A : out std_logic;
      BRAM_WEN_A : out std_logic_vector(0 to 3);
      BRAM_Addr_A : out std_logic_vector(0 to 31);
      BRAM_Din_A : in std_logic_vector(0 to 31);
      BRAM_Dout_A : out std_logic_vector(0 to 31)
    );
  end component;

  attribute box_type of lmb_bram_if_cntlr_0_wrapper: component is "black_box";

  component lmb_bram_if_cntlr_1_wrapper is
    port (
      LMB_Clk : in std_logic;
      LMB_Rst : in std_logic;
      LMB_ABus : in std_logic_vector(0 to 31);
      LMB_WriteDBus : in std_logic_vector(0 to 31);
      LMB_AddrStrobe : in std_logic;
      LMB_ReadStrobe : in std_logic;
      LMB_WriteStrobe : in std_logic;
      LMB_BE : in std_logic_vector(0 to 3);
      Sl_DBus : out std_logic_vector(0 to 31);
      Sl_Ready : out std_logic;
      BRAM_Rst_A : out std_logic;
      BRAM_Clk_A : out std_logic;
      BRAM_EN_A : out std_logic;
      BRAM_WEN_A : out std_logic_vector(0 to 3);
      BRAM_Addr_A : out std_logic_vector(0 to 31);
      BRAM_Din_A : in std_logic_vector(0 to 31);
      BRAM_Dout_A : out std_logic_vector(0 to 31)
    );
  end component;

  attribute box_type of lmb_bram_if_cntlr_1_wrapper: component is "black_box";

  component lmb_v10_0_wrapper is
    port (
      LMB_Clk : in std_logic;
      SYS_Rst : in std_logic;
      LMB_Rst : out std_logic;
      M_ABus : in std_logic_vector(0 to 31);
      M_ReadStrobe : in std_logic;
      M_WriteStrobe : in std_logic;
      M_AddrStrobe : in std_logic;
      M_DBus : in std_logic_vector(0 to 31);
      M_BE : in std_logic_vector(0 to 3);
      Sl_DBus : in std_logic_vector(0 to 31);
      Sl_Ready : in std_logic_vector(0 to 0);
      LMB_ABus : out std_logic_vector(0 to 31);
      LMB_ReadStrobe : out std_logic;
      LMB_WriteStrobe : out std_logic;
      LMB_AddrStrobe : out std_logic;
      LMB_ReadDBus : out std_logic_vector(0 to 31);
      LMB_WriteDBus : out std_logic_vector(0 to 31);
      LMB_Ready : out std_logic;
      LMB_BE : out std_logic_vector(0 to 3)
    );
  end component;

  attribute box_type of lmb_v10_0_wrapper: component is "black_box";

  component lmb_v10_1_wrapper is
    port (
      LMB_Clk : in std_logic;
      SYS_Rst : in std_logic;
      LMB_Rst : out std_logic;
      M_ABus : in std_logic_vector(0 to 31);
      M_ReadStrobe : in std_logic;
      M_WriteStrobe : in std_logic;
      M_AddrStrobe : in std_logic;
      M_DBus : in std_logic_vector(0 to 31);
      M_BE : in std_logic_vector(0 to 3);
      Sl_DBus : in std_logic_vector(0 to 31);
      Sl_Ready : in std_logic_vector(0 to 0);
      LMB_ABus : out std_logic_vector(0 to 31);
      LMB_ReadStrobe : out std_logic;
      LMB_WriteStrobe : out std_logic;
      LMB_AddrStrobe : out std_logic;
      LMB_ReadDBus : out std_logic_vector(0 to 31);
      LMB_WriteDBus : out std_logic_vector(0 to 31);
      LMB_Ready : out std_logic;
      LMB_BE : out std_logic_vector(0 to 3)
    );
  end component;

  attribute box_type of lmb_v10_1_wrapper: component is "black_box";

  -- Internal signals

  signal fsl_v20_0_FSL_M_Control : std_logic;
  signal fsl_v20_0_FSL_M_Data : std_logic_vector(0 to 31);
  signal fsl_v20_0_FSL_M_Full : std_logic;
  signal fsl_v20_0_FSL_M_Write : std_logic;
  signal fsl_v20_0_FSL_S_Control : std_logic;
  signal fsl_v20_0_FSL_S_Data : std_logic_vector(0 to 31);
  signal fsl_v20_0_FSL_S_Exists : std_logic;
  signal fsl_v20_0_FSL_S_Read : std_logic;
  signal fsl_v20_0_OPB_Rst : std_logic;
  signal lmb_bram_if_cntlr_0_BRAM_PORT_BRAM_Addr : std_logic_vector(0 to 31);
  signal lmb_bram_if_cntlr_0_BRAM_PORT_BRAM_Clk : std_logic;
  signal lmb_bram_if_cntlr_0_BRAM_PORT_BRAM_Din : std_logic_vector(0 to 31);
  signal lmb_bram_if_cntlr_0_BRAM_PORT_BRAM_Dout : std_logic_vector(0 to 31);
  signal lmb_bram_if_cntlr_0_BRAM_PORT_BRAM_EN : std_logic;
  signal lmb_bram_if_cntlr_0_BRAM_PORT_BRAM_Rst : std_logic;
  signal lmb_bram_if_cntlr_0_BRAM_PORT_BRAM_WEN : std_logic_vector(0 to 3);
  signal lmb_bram_if_cntlr_1_BRAM_PORT_BRAM_Addr : std_logic_vector(0 to 31);
  signal lmb_bram_if_cntlr_1_BRAM_PORT_BRAM_Clk : std_logic;
  signal lmb_bram_if_cntlr_1_BRAM_PORT_BRAM_Din : std_logic_vector(0 to 31);
  signal lmb_bram_if_cntlr_1_BRAM_PORT_BRAM_Dout : std_logic_vector(0 to 31);
  signal lmb_bram_if_cntlr_1_BRAM_PORT_BRAM_EN : std_logic;
  signal lmb_bram_if_cntlr_1_BRAM_PORT_BRAM_Rst : std_logic;
  signal lmb_bram_if_cntlr_1_BRAM_PORT_BRAM_WEN : std_logic_vector(0 to 3);
  signal lmb_v10_0_LMB_ABus : std_logic_vector(0 to 31);
  signal lmb_v10_0_LMB_AddrStrobe : std_logic;
  signal lmb_v10_0_LMB_BE : std_logic_vector(0 to 3);
  signal lmb_v10_0_LMB_ReadDBus : std_logic_vector(0 to 31);
  signal lmb_v10_0_LMB_ReadStrobe : std_logic;
  signal lmb_v10_0_LMB_Ready : std_logic;
  signal lmb_v10_0_LMB_WriteDBus : std_logic_vector(0 to 31);
  signal lmb_v10_0_LMB_WriteStrobe : std_logic;
  signal lmb_v10_0_M_ABus : std_logic_vector(0 to 31);
  signal lmb_v10_0_M_AddrStrobe : std_logic;
  signal lmb_v10_0_M_BE : std_logic_vector(0 to 3);
  signal lmb_v10_0_M_DBus : std_logic_vector(0 to 31);
  signal lmb_v10_0_M_ReadStrobe : std_logic;
  signal lmb_v10_0_M_WriteStrobe : std_logic;
  signal lmb_v10_0_OPB_Rst : std_logic;
  signal lmb_v10_0_Sl_DBus : std_logic_vector(0 to 31);
  signal lmb_v10_0_Sl_Ready : std_logic_vector(0 to 0);
  signal lmb_v10_1_LMB_ABus : std_logic_vector(0 to 31);
  signal lmb_v10_1_LMB_AddrStrobe : std_logic;
  signal lmb_v10_1_LMB_BE : std_logic_vector(0 to 3);
  signal lmb_v10_1_LMB_ReadDBus : std_logic_vector(0 to 31);
  signal lmb_v10_1_LMB_ReadStrobe : std_logic;
  signal lmb_v10_1_LMB_Ready : std_logic;
  signal lmb_v10_1_LMB_WriteDBus : std_logic_vector(0 to 31);
  signal lmb_v10_1_LMB_WriteStrobe : std_logic;
  signal lmb_v10_1_M_ABus : std_logic_vector(0 to 31);
  signal lmb_v10_1_M_AddrStrobe : std_logic;
  signal lmb_v10_1_M_ReadStrobe : std_logic;
  signal lmb_v10_1_OPB_Rst : std_logic;
  signal lmb_v10_1_Sl_DBus : std_logic_vector(0 to 31);
  signal lmb_v10_1_Sl_Ready : std_logic_vector(0 to 0);
  signal mb_opb_M_ABus : std_logic_vector(0 to 63);
  signal mb_opb_M_BE : std_logic_vector(0 to 7);
  signal mb_opb_M_DBus : std_logic_vector(0 to 63);
  signal mb_opb_M_RNW : std_logic_vector(0 to 1);
  signal mb_opb_M_busLock : std_logic_vector(0 to 1);
  signal mb_opb_M_request : std_logic_vector(0 to 1);
  signal mb_opb_M_select : std_logic_vector(0 to 1);
  signal mb_opb_M_seqAddr : std_logic_vector(0 to 1);
  signal mb_opb_OPB_ABus : std_logic_vector(0 to 31);
  signal mb_opb_OPB_BE : std_logic_vector(0 to 3);
  signal mb_opb_OPB_DBus : std_logic_vector(0 to 31);
  signal mb_opb_OPB_MGrant : std_logic_vector(0 to 1);
  signal mb_opb_OPB_RNW : std_logic;
  signal mb_opb_OPB_Rst : std_logic;
  signal mb_opb_OPB_errAck : std_logic;
  signal mb_opb_OPB_retry : std_logic;
  signal mb_opb_OPB_select : std_logic;
  signal mb_opb_OPB_seqAddr : std_logic;
  signal mb_opb_OPB_timeout : std_logic;
  signal mb_opb_OPB_xferAck : std_logic;
  signal mb_opb_Sl_DBus : std_logic_vector(0 to 31);
  signal mb_opb_Sl_errAck : std_logic_vector(0 to 0);
  signal mb_opb_Sl_retry : std_logic_vector(0 to 0);
  signal mb_opb_Sl_toutSup : std_logic_vector(0 to 0);
  signal mb_opb_Sl_xferAck : std_logic_vector(0 to 0);
  signal net_gnd0 : std_logic;
  signal net_gnd1 : std_logic_vector(0 to 0);
  signal net_gnd2 : std_logic_vector(0 to 1);
  signal net_gnd4 : std_logic_vector(0 to 3);
  signal net_gnd5 : std_logic_vector(0 to 4);
  signal net_gnd32 : std_logic_vector(0 to 31);
  signal net_vcc1 : std_logic_vector(0 to 0);
  signal net_vcc2 : std_logic_vector(0 to 1);
  signal opb_external_memory_0_LEDS_DEBUG : std_logic_vector(0 to 15);
  signal opb_external_memory_0_OMA_ACTIVE : std_logic;
  signal opb_external_memory_0_OMA_ADDRESS : std_logic_vector(0 to 31);
  signal opb_external_memory_0_OMA_BE : std_logic_vector(0 to 3);
  signal opb_external_memory_0_OMA_DATA_I : std_logic_vector(0 to 31);
  signal opb_external_memory_0_OMA_DATA_O : std_logic_vector(0 to 31);
  signal opb_external_memory_0_OMA_RW : std_logic;
  signal opb_external_memory_0_OMA_VALID : std_logic;
  signal sys_clk_s : std_logic;
  signal sys_rst_s : std_logic;

begin

  -- Internal assignments

  sys_clk_s <= sys_clk_pin;
  sys_rst_s <= sys_rst_pin;
  opb_external_memory_0_OMA_DATA_O_pin <= opb_external_memory_0_OMA_DATA_O;
  opb_external_memory_0_OMA_DATA_I <= opb_external_memory_0_OMA_DATA_I_pin;
  opb_external_memory_0_OMA_VALID <= opb_external_memory_0_OMA_VALID_pin;
  opb_external_memory_0_OMA_ADDRESS_pin <= opb_external_memory_0_OMA_ADDRESS;
  opb_external_memory_0_OMA_RW_pin <= opb_external_memory_0_OMA_RW;
  opb_external_memory_0_OMA_ACTIVE_pin <= opb_external_memory_0_OMA_ACTIVE;
  opb_external_memory_0_LEDS_DEBUG_pin <= opb_external_memory_0_LEDS_DEBUG;
  opb_external_memory_0_OMA_BE_pin <= opb_external_memory_0_OMA_BE;
  net_gnd0 <= '0';
  net_gnd1(0 to 0) <= B"0";
  net_gnd2(0 to 1) <= B"00";
  net_gnd32(0 to 31) <= B"00000000000000000000000000000000";
  net_gnd4(0 to 3) <= B"0000";
  net_gnd5(0 to 4) <= B"00000";
  net_vcc1(0 to 0) <= B"1";
  net_vcc2(0 to 1) <= B"11";

  microblaze_0 : microblaze_0_wrapper
    port map (
      CLK => sys_clk_s,
      RESET => mb_opb_OPB_Rst,
      INTERRUPT => net_gnd0,
      DEBUG_RST => net_gnd0,
      EXT_BRK => net_gnd0,
      EXT_NM_BRK => net_gnd0,
      DBG_STOP => net_gnd0,
      INSTR => lmb_v10_1_LMB_ReadDBus,
      I_ADDRTAG => open,
      IREADY => lmb_v10_1_LMB_Ready,
      IWAIT => net_gnd0,
      INSTR_ADDR => lmb_v10_1_M_ABus,
      IFETCH => lmb_v10_1_M_ReadStrobe,
      I_AS => lmb_v10_1_M_AddrStrobe,
      DATA_READ => lmb_v10_0_LMB_ReadDBus,
      DREADY => lmb_v10_0_LMB_Ready,
      DWAIT => net_gnd0,
      DATA_WRITE => lmb_v10_0_M_DBus,
      DATA_ADDR => lmb_v10_0_M_ABus,
      D_ADDRTAG => open,
      D_AS => lmb_v10_0_M_AddrStrobe,
      READ_STROBE => lmb_v10_0_M_ReadStrobe,
      WRITE_STROBE => lmb_v10_0_M_WriteStrobe,
      BYTE_ENABLE => lmb_v10_0_M_BE,
      DM_ABUS => mb_opb_M_ABus(0 to 31),
      DM_BE => mb_opb_M_BE(0 to 3),
      DM_BUSLOCK => mb_opb_M_busLock(0),
      DM_DBUS => mb_opb_M_DBus(0 to 31),
      DM_REQUEST => mb_opb_M_request(0),
      DM_RNW => mb_opb_M_RNW(0),
      DM_SELECT => mb_opb_M_select(0),
      DM_SEQADDR => mb_opb_M_seqAddr(0),
      DOPB_DBUS => mb_opb_OPB_DBus,
      DOPB_ERRACK => mb_opb_OPB_errAck,
      DOPB_MGRANT => mb_opb_OPB_MGrant(0),
      DOPB_RETRY => mb_opb_OPB_retry,
      DOPB_TIMEOUT => mb_opb_OPB_timeout,
      DOPB_XFERACK => mb_opb_OPB_xferAck,
      IM_ABUS => mb_opb_M_ABus(32 to 63),
      IM_BE => mb_opb_M_BE(4 to 7),
      IM_BUSLOCK => mb_opb_M_busLock(1),
      IM_DBUS => mb_opb_M_DBus(32 to 63),
      IM_REQUEST => mb_opb_M_request(1),
      IM_RNW => mb_opb_M_RNW(1),
      IM_SELECT => mb_opb_M_select(1),
      IM_SEQADDR => mb_opb_M_seqAddr(1),
      IOPB_DBUS => mb_opb_OPB_DBus,
      IOPB_ERRACK => mb_opb_OPB_errAck,
      IOPB_MGRANT => mb_opb_OPB_MGrant(1),
      IOPB_RETRY => mb_opb_OPB_retry,
      IOPB_TIMEOUT => mb_opb_OPB_timeout,
      IOPB_XFERACK => mb_opb_OPB_xferAck,
      DBG_CLK => net_gnd0,
      DBG_TDI => net_gnd0,
      DBG_TDO => open,
      DBG_REG_EN => net_gnd5,
      DBG_CAPTURE => net_gnd0,
      DBG_UPDATE => net_gnd0,
      VALID_INSTR => open,
      PC_EX => open,
      REG_WRITE => open,
      REG_ADDR => open,
      MSR_REG => open,
      NEW_REG_VALUE => open,
      PIPE_RUNNING => open,
      INTERRUPT_TAKEN => open,
      JUMP_TAKEN => open,
      PREFETCH_ADDR => open,
      MB_Halted => open,
      Trace_Branch_Instr => open,
      Trace_Delay_Slot => open,
      Trace_Data_Address => open,
      Trace_AS => open,
      Trace_Data_Read => open,
      Trace_Data_Write => open,
      Trace_DCache_Req => open,
      Trace_DCache_Hit => open,
      Trace_ICache_Req => open,
      Trace_ICache_Hit => open,
      Trace_Instr_EX => open,
      FSL0_S_CLK => open,
      FSL0_S_READ => fsl_v20_0_FSL_S_Read,
      FSL0_S_DATA => fsl_v20_0_FSL_S_Data,
      FSL0_S_CONTROL => fsl_v20_0_FSL_S_Control,
      FSL0_S_EXISTS => fsl_v20_0_FSL_S_Exists,
      FSL0_M_CLK => open,
      FSL0_M_WRITE => open,
      FSL0_M_DATA => open,
      FSL0_M_CONTROL => open,
      FSL0_M_FULL => net_gnd0,
      FSL1_S_CLK => open,
      FSL1_S_READ => open,
      FSL1_S_DATA => net_gnd32,
      FSL1_S_CONTROL => net_gnd0,
      FSL1_S_EXISTS => net_gnd0,
      FSL1_M_CLK => open,
      FSL1_M_WRITE => open,
      FSL1_M_DATA => open,
      FSL1_M_CONTROL => open,
      FSL1_M_FULL => net_gnd0,
      FSL2_S_CLK => open,
      FSL2_S_READ => open,
      FSL2_S_DATA => net_gnd32,
      FSL2_S_CONTROL => net_gnd0,
      FSL2_S_EXISTS => net_gnd0,
      FSL2_M_CLK => open,
      FSL2_M_WRITE => open,
      FSL2_M_DATA => open,
      FSL2_M_CONTROL => open,
      FSL2_M_FULL => net_gnd0,
      FSL3_S_CLK => open,
      FSL3_S_READ => open,
      FSL3_S_DATA => net_gnd32,
      FSL3_S_CONTROL => net_gnd0,
      FSL3_S_EXISTS => net_gnd0,
      FSL3_M_CLK => open,
      FSL3_M_WRITE => open,
      FSL3_M_DATA => open,
      FSL3_M_CONTROL => open,
      FSL3_M_FULL => net_gnd0,
      FSL4_S_CLK => open,
      FSL4_S_READ => open,
      FSL4_S_DATA => net_gnd32,
      FSL4_S_CONTROL => net_gnd0,
      FSL4_S_EXISTS => net_gnd0,
      FSL4_M_CLK => open,
      FSL4_M_WRITE => open,
      FSL4_M_DATA => open,
      FSL4_M_CONTROL => open,
      FSL4_M_FULL => net_gnd0,
      FSL5_S_CLK => open,
      FSL5_S_READ => open,
      FSL5_S_DATA => net_gnd32,
      FSL5_S_CONTROL => net_gnd0,
      FSL5_S_EXISTS => net_gnd0,
      FSL5_M_CLK => open,
      FSL5_M_WRITE => open,
      FSL5_M_DATA => open,
      FSL5_M_CONTROL => open,
      FSL5_M_FULL => net_gnd0,
      FSL6_S_CLK => open,
      FSL6_S_READ => open,
      FSL6_S_DATA => net_gnd32,
      FSL6_S_CONTROL => net_gnd0,
      FSL6_S_EXISTS => net_gnd0,
      FSL6_M_CLK => open,
      FSL6_M_WRITE => open,
      FSL6_M_DATA => open,
      FSL6_M_CONTROL => open,
      FSL6_M_FULL => net_gnd0,
      FSL7_S_CLK => open,
      FSL7_S_READ => open,
      FSL7_S_DATA => net_gnd32,
      FSL7_S_CONTROL => net_gnd0,
      FSL7_S_EXISTS => net_gnd0,
      FSL7_M_CLK => open,
      FSL7_M_WRITE => open,
      FSL7_M_DATA => open,
      FSL7_M_CONTROL => open,
      FSL7_M_FULL => net_gnd0,
      ICACHE_FSL_IN_CLK => open,
      ICACHE_FSL_IN_READ => open,
      ICACHE_FSL_IN_DATA => net_gnd32,
      ICACHE_FSL_IN_CONTROL => net_gnd0,
      ICACHE_FSL_IN_EXISTS => net_gnd0,
      ICACHE_FSL_OUT_CLK => open,
      ICACHE_FSL_OUT_WRITE => open,
      ICACHE_FSL_OUT_DATA => open,
      ICACHE_FSL_OUT_CONTROL => open,
      ICACHE_FSL_OUT_FULL => net_gnd0,
      DCACHE_FSL_IN_CLK => open,
      DCACHE_FSL_IN_READ => open,
      DCACHE_FSL_IN_DATA => net_gnd32,
      DCACHE_FSL_IN_CONTROL => net_gnd0,
      DCACHE_FSL_IN_EXISTS => net_gnd0,
      DCACHE_FSL_OUT_CLK => open,
      DCACHE_FSL_OUT_WRITE => open,
      DCACHE_FSL_OUT_DATA => open,
      DCACHE_FSL_OUT_CONTROL => open,
      DCACHE_FSL_OUT_FULL => net_gnd0
    );

  mb_opb : mb_opb_wrapper
    port map (
      OPB_Clk => sys_clk_s,
      OPB_Rst => mb_opb_OPB_Rst,
      SYS_Rst => sys_rst_s,
      Debug_SYS_Rst => net_gnd0,
      WDT_Rst => net_gnd0,
      M_ABus => mb_opb_M_ABus,
      M_BE => mb_opb_M_BE,
      M_beXfer => net_gnd2,
      M_busLock => mb_opb_M_busLock,
      M_DBus => mb_opb_M_DBus,
      M_DBusEn => net_gnd2,
      M_DBusEn32_63 => net_vcc2,
      M_dwXfer => net_gnd2,
      M_fwXfer => net_gnd2,
      M_hwXfer => net_gnd2,
      M_request => mb_opb_M_request,
      M_RNW => mb_opb_M_RNW,
      M_select => mb_opb_M_select,
      M_seqAddr => mb_opb_M_seqAddr,
      Sl_beAck => net_gnd1(0 to 0),
      Sl_DBus => mb_opb_Sl_DBus,
      Sl_DBusEn => net_vcc1(0 to 0),
      Sl_DBusEn32_63 => net_vcc1(0 to 0),
      Sl_errAck => mb_opb_Sl_errAck(0 to 0),
      Sl_dwAck => net_gnd1(0 to 0),
      Sl_fwAck => net_gnd1(0 to 0),
      Sl_hwAck => net_gnd1(0 to 0),
      Sl_retry => mb_opb_Sl_retry(0 to 0),
      Sl_toutSup => mb_opb_Sl_toutSup(0 to 0),
      Sl_xferAck => mb_opb_Sl_xferAck(0 to 0),
      OPB_MRequest => open,
      OPB_ABus => mb_opb_OPB_ABus,
      OPB_BE => mb_opb_OPB_BE,
      OPB_beXfer => open,
      OPB_beAck => open,
      OPB_busLock => open,
      OPB_rdDBus => open,
      OPB_wrDBus => open,
      OPB_DBus => mb_opb_OPB_DBus,
      OPB_errAck => mb_opb_OPB_errAck,
      OPB_dwAck => open,
      OPB_dwXfer => open,
      OPB_fwAck => open,
      OPB_fwXfer => open,
      OPB_hwAck => open,
      OPB_hwXfer => open,
      OPB_MGrant => mb_opb_OPB_MGrant,
      OPB_pendReq => open,
      OPB_retry => mb_opb_OPB_retry,
      OPB_RNW => mb_opb_OPB_RNW,
      OPB_select => mb_opb_OPB_select,
      OPB_seqAddr => mb_opb_OPB_seqAddr,
      OPB_timeout => mb_opb_OPB_timeout,
      OPB_toutSup => open,
      OPB_xferAck => mb_opb_OPB_xferAck
    );

  opb_external_memory_0 : opb_external_memory_0_wrapper
    port map (
      OPB_Clk => sys_clk_s,
      OPB_Rst => mb_opb_OPB_Rst,
      Sl_DBus => mb_opb_Sl_DBus,
      Sl_errAck => mb_opb_Sl_errAck(0),
      Sl_retry => mb_opb_Sl_retry(0),
      Sl_toutSup => mb_opb_Sl_toutSup(0),
      Sl_xferAck => mb_opb_Sl_xferAck(0),
      OPB_ABus => mb_opb_OPB_ABus,
      OPB_BE => mb_opb_OPB_BE,
      OPB_DBus => mb_opb_OPB_DBus,
      OPB_RNW => mb_opb_OPB_RNW,
      OPB_select => mb_opb_OPB_select,
      OPB_seqAddr => mb_opb_OPB_seqAddr,
      OMA_DATA_O => opb_external_memory_0_OMA_DATA_O,
      OMA_DATA_I => opb_external_memory_0_OMA_DATA_I,
      OMA_VALID => opb_external_memory_0_OMA_VALID,
      OMA_ADDRESS => opb_external_memory_0_OMA_ADDRESS,
      OMA_RW => opb_external_memory_0_OMA_RW,
      OMA_ACTIVE => opb_external_memory_0_OMA_ACTIVE,
      LEDS_DEBUG => opb_external_memory_0_LEDS_DEBUG,
      OMA_BE => opb_external_memory_0_OMA_BE
    );

  cpu_identifier_0 : cpu_identifier_0_wrapper
    port map (
      FSL_Clk => sys_clk_s,
      FSL_Rst => fsl_v20_0_OPB_Rst,
      FSL_S_Clk => open,
      FSL_S_Read => open,
      FSL_S_Data => net_gnd32,
      FSL_S_Control => net_gnd0,
      FSL_S_Exists => net_gnd0,
      FSL_M_Clk => open,
      FSL_M_Write => fsl_v20_0_FSL_M_Write,
      FSL_M_Data => fsl_v20_0_FSL_M_Data,
      FSL_M_Control => fsl_v20_0_FSL_M_Control,
      FSL_M_Full => fsl_v20_0_FSL_M_Full
    );

  fsl_v20_0 : fsl_v20_0_wrapper
    port map (
      FSL_Clk => sys_clk_s,
      SYS_Rst => sys_rst_s,
      FSL_Rst => fsl_v20_0_OPB_Rst,
      FSL_M_Clk => sys_clk_s,
      FSL_M_Data => fsl_v20_0_FSL_M_Data,
      FSL_M_Control => fsl_v20_0_FSL_M_Control,
      FSL_M_Write => fsl_v20_0_FSL_M_Write,
      FSL_M_Full => fsl_v20_0_FSL_M_Full,
      FSL_S_Clk => sys_rst_s,
      FSL_S_Data => fsl_v20_0_FSL_S_Data,
      FSL_S_Control => fsl_v20_0_FSL_S_Control,
      FSL_S_Read => fsl_v20_0_FSL_S_Read,
      FSL_S_Exists => fsl_v20_0_FSL_S_Exists,
      FSL_Full => open,
      FSL_Has_Data => open
    );

  bram_block_0 : bram_block_0_wrapper
    port map (
      BRAM_Rst_A => lmb_bram_if_cntlr_0_BRAM_PORT_BRAM_Rst,
      BRAM_Clk_A => lmb_bram_if_cntlr_0_BRAM_PORT_BRAM_Clk,
      BRAM_EN_A => lmb_bram_if_cntlr_0_BRAM_PORT_BRAM_EN,
      BRAM_WEN_A => lmb_bram_if_cntlr_0_BRAM_PORT_BRAM_WEN,
      BRAM_Addr_A => lmb_bram_if_cntlr_0_BRAM_PORT_BRAM_Addr,
      BRAM_Din_A => lmb_bram_if_cntlr_0_BRAM_PORT_BRAM_Din,
      BRAM_Dout_A => lmb_bram_if_cntlr_0_BRAM_PORT_BRAM_Dout,
      BRAM_Rst_B => lmb_bram_if_cntlr_1_BRAM_PORT_BRAM_Rst,
      BRAM_Clk_B => lmb_bram_if_cntlr_1_BRAM_PORT_BRAM_Clk,
      BRAM_EN_B => lmb_bram_if_cntlr_1_BRAM_PORT_BRAM_EN,
      BRAM_WEN_B => lmb_bram_if_cntlr_1_BRAM_PORT_BRAM_WEN,
      BRAM_Addr_B => lmb_bram_if_cntlr_1_BRAM_PORT_BRAM_Addr,
      BRAM_Din_B => lmb_bram_if_cntlr_1_BRAM_PORT_BRAM_Din,
      BRAM_Dout_B => lmb_bram_if_cntlr_1_BRAM_PORT_BRAM_Dout
    );

  lmb_bram_if_cntlr_0 : lmb_bram_if_cntlr_0_wrapper
    port map (
      LMB_Clk => sys_clk_s,
      LMB_Rst => lmb_v10_0_OPB_Rst,
      LMB_ABus => lmb_v10_0_LMB_ABus,
      LMB_WriteDBus => lmb_v10_0_LMB_WriteDBus,
      LMB_AddrStrobe => lmb_v10_0_LMB_AddrStrobe,
      LMB_ReadStrobe => lmb_v10_0_LMB_ReadStrobe,
      LMB_WriteStrobe => lmb_v10_0_LMB_WriteStrobe,
      LMB_BE => lmb_v10_0_LMB_BE,
      Sl_DBus => lmb_v10_0_Sl_DBus,
      Sl_Ready => lmb_v10_0_Sl_Ready(0),
      BRAM_Rst_A => lmb_bram_if_cntlr_0_BRAM_PORT_BRAM_Rst,
      BRAM_Clk_A => lmb_bram_if_cntlr_0_BRAM_PORT_BRAM_Clk,
      BRAM_EN_A => lmb_bram_if_cntlr_0_BRAM_PORT_BRAM_EN,
      BRAM_WEN_A => lmb_bram_if_cntlr_0_BRAM_PORT_BRAM_WEN,
      BRAM_Addr_A => lmb_bram_if_cntlr_0_BRAM_PORT_BRAM_Addr,
      BRAM_Din_A => lmb_bram_if_cntlr_0_BRAM_PORT_BRAM_Din,
      BRAM_Dout_A => lmb_bram_if_cntlr_0_BRAM_PORT_BRAM_Dout
    );

  lmb_bram_if_cntlr_1 : lmb_bram_if_cntlr_1_wrapper
    port map (
      LMB_Clk => sys_clk_s,
      LMB_Rst => lmb_v10_1_OPB_Rst,
      LMB_ABus => lmb_v10_1_LMB_ABus,
      LMB_WriteDBus => lmb_v10_1_LMB_WriteDBus,
      LMB_AddrStrobe => lmb_v10_1_LMB_AddrStrobe,
      LMB_ReadStrobe => lmb_v10_1_LMB_ReadStrobe,
      LMB_WriteStrobe => lmb_v10_1_LMB_WriteStrobe,
      LMB_BE => lmb_v10_1_LMB_BE,
      Sl_DBus => lmb_v10_1_Sl_DBus,
      Sl_Ready => lmb_v10_1_Sl_Ready(0),
      BRAM_Rst_A => lmb_bram_if_cntlr_1_BRAM_PORT_BRAM_Rst,
      BRAM_Clk_A => lmb_bram_if_cntlr_1_BRAM_PORT_BRAM_Clk,
      BRAM_EN_A => lmb_bram_if_cntlr_1_BRAM_PORT_BRAM_EN,
      BRAM_WEN_A => lmb_bram_if_cntlr_1_BRAM_PORT_BRAM_WEN,
      BRAM_Addr_A => lmb_bram_if_cntlr_1_BRAM_PORT_BRAM_Addr,
      BRAM_Din_A => lmb_bram_if_cntlr_1_BRAM_PORT_BRAM_Din,
      BRAM_Dout_A => lmb_bram_if_cntlr_1_BRAM_PORT_BRAM_Dout
    );

  lmb_v10_0 : lmb_v10_0_wrapper
    port map (
      LMB_Clk => sys_clk_s,
      SYS_Rst => sys_rst_s,
      LMB_Rst => lmb_v10_0_OPB_Rst,
      M_ABus => lmb_v10_0_M_ABus,
      M_ReadStrobe => lmb_v10_0_M_ReadStrobe,
      M_WriteStrobe => lmb_v10_0_M_WriteStrobe,
      M_AddrStrobe => lmb_v10_0_M_AddrStrobe,
      M_DBus => lmb_v10_0_M_DBus,
      M_BE => lmb_v10_0_M_BE,
      Sl_DBus => lmb_v10_0_Sl_DBus,
      Sl_Ready => lmb_v10_0_Sl_Ready(0 to 0),
      LMB_ABus => lmb_v10_0_LMB_ABus,
      LMB_ReadStrobe => lmb_v10_0_LMB_ReadStrobe,
      LMB_WriteStrobe => lmb_v10_0_LMB_WriteStrobe,
      LMB_AddrStrobe => lmb_v10_0_LMB_AddrStrobe,
      LMB_ReadDBus => lmb_v10_0_LMB_ReadDBus,
      LMB_WriteDBus => lmb_v10_0_LMB_WriteDBus,
      LMB_Ready => lmb_v10_0_LMB_Ready,
      LMB_BE => lmb_v10_0_LMB_BE
    );

  lmb_v10_1 : lmb_v10_1_wrapper
    port map (
      LMB_Clk => sys_clk_s,
      SYS_Rst => sys_rst_s,
      LMB_Rst => lmb_v10_1_OPB_Rst,
      M_ABus => lmb_v10_1_M_ABus,
      M_ReadStrobe => lmb_v10_1_M_ReadStrobe,
      M_WriteStrobe => net_gnd0,
      M_AddrStrobe => lmb_v10_1_M_AddrStrobe,
      M_DBus => net_gnd32,
      M_BE => net_gnd4,
      Sl_DBus => lmb_v10_1_Sl_DBus,
      Sl_Ready => lmb_v10_1_Sl_Ready(0 to 0),
      LMB_ABus => lmb_v10_1_LMB_ABus,
      LMB_ReadStrobe => lmb_v10_1_LMB_ReadStrobe,
      LMB_WriteStrobe => lmb_v10_1_LMB_WriteStrobe,
      LMB_AddrStrobe => lmb_v10_1_LMB_AddrStrobe,
      LMB_ReadDBus => lmb_v10_1_LMB_ReadDBus,
      LMB_WriteDBus => lmb_v10_1_LMB_WriteDBus,
      LMB_Ready => lmb_v10_1_LMB_Ready,
      LMB_BE => lmb_v10_1_LMB_BE
    );

end architecture STRUCTURE;

