----------------------------------------------------------------------------------
-- Company: NTNU
-- Engineer: Kenneth Østby <kenneo@idi.ntnu.no>
-- 
-- Create Date:    13:58:29 11/20/2006 
-- Design Name: 
-- Module Name:    toplevel - Behavioral 
-- Project Name: 
-- Target Devices: 
-- Tool versions: 
-- Description: 
--
-- Dependencies: 
--
-- Revision: 
-- Revision 0.01 - File Created
-- Additional Comments: 
--
----------------------------------------------------------------------------------
library IEEE;
use IEEE.STD_LOGIC_1164.ALL;
use IEEE.STD_LOGIC_ARITH.ALL;
use IEEE.STD_LOGIC_UNSIGNED.ALL;

---- Uncomment the following library declaration if instantiating
---- any Xilinx primitives in this code.
library UNISIM;
use UNISIM.VComponents.all;

use work.coreStuff.all;

entity toplevel is
	PORT(
		sys_clk_pin 				: IN std_logic;
		reset 						: IN std_logic;
		fpga_0_LEDS_GPIO_d_out_pin 	: OUT std_logic_vector(0 to 15);
		PCI_ADDS					: in  STD_LOGIC; 
		PCI_EMPTY 					: in  STD_LOGIC; 
		PCI_BUSY					: in  STD_LOGIC; 
		PCI_RW						: out  STD_LOGIC; 
		PCI_RENWEN 					: out  STD_LOGIC; 
		PCI_ADIO					: inout  STD_LOGIC_VECTOR (0 to 31));
end toplevel;

architecture Behavioral of toplevel is
		signal OMA_VALID 	: std_logic;    
		signal OMA_DATA_I	: std_logic_vector(0 to 31) := (others =>'0');
		signal OMA_DATA_O	: std_logic_vector(0 to 31) := (others =>'0');
		signal OMA_ADDRESS	: std_logic_vector(0 to 31) := x"DEADBEEF";
		signal OMA_RW		: std_logic;
		signal OMA_ACTIVE	: std_logic;
		signal OMA_BE		: std_logic_vector (0 to 3) := (others => '0');

		signal CACHE_VALID 	: std_logic;    
		signal CACHE_DATA_I	: std_logic_vector(0 to 31) := (others =>'0');
		signal CACHE_DATA_O	: std_logic_vector(0 to 31) := (others =>'0');
		signal CACHE_ADDRESS	: std_logic_vector(0 to 31) := ( others => '0');
		signal CACHE_RW		: std_logic;
		signal CACHE_ACTIVE	: std_logic;
		signal CACHE_BE		: std_logic_vector (0 to 3) := (others => '0');
		
		signal CORE_VALID 	: corebit;    
		signal CORE_DATA_I	: corevector := (others => (others =>'0'));
		signal CORE_DATA_O	: corevector := (others => (others =>'0'));
		signal CORE_ADDRESS	: corevector := (others => (others =>'0'));
		signal CORE_RW		: corebit;
		signal CORE_ACTIVE	: corebit;
		signal CORE_BE		: corebe;
		
		
		signal sPCI_ADDS	: std_logic := '0';
		signal sPCI_EMPTY 	: std_logic := '0';
		signal sPCI_BUSY	: std_logic := '0';
		signal sPCI_RW 		: std_logic := '0';
		signal sPCI_RENWEN 	: std_logic := '1';
		
		signal rst_inv 		: std_logic;
		signal rst_internal : std_logic;
		
		
	COMPONENT core
	PORT(
		sys_clk_pin : IN std_logic;
		sys_rst_pin : IN std_logic;
		opb_external_memory_0_OMA_DATA_I_pin 	: IN std_logic_vector(0 to 31);
		opb_external_memory_0_OMA_VALID_pin 	: IN std_logic;
		opb_external_memory_1_OMA_DATA_I_pin 	: IN std_logic_vector(0 to 31);
		opb_external_memory_1_OMA_VALID_pin 	: IN std_logic;          
		opb_external_memory_0_OMA_DATA_O_pin 	: OUT std_logic_vector(0 to 31);
		opb_external_memory_0_OMA_ADDRESS_pin 	: OUT std_logic_vector(0 to 31);
		opb_external_memory_0_OMA_RW_pin 		: OUT std_logic;
		opb_external_memory_0_OMA_ACTIVE_pin 	: OUT std_logic;
		opb_external_memory_0_LEDS_DEBUG_pin 	: OUT std_logic_vector(0 to 15);
		opb_external_memory_0_OMA_BE_pin 		: OUT std_logic_vector(0 to 3);
		opb_external_memory_1_OMA_DATA_O_pin 	: OUT std_logic_vector(0 to 31);
		opb_external_memory_1_OMA_ADDRESS_pin 	: OUT std_logic_vector(0 to 31);
		opb_external_memory_1_OMA_RW_pin 		: OUT std_logic;
		opb_external_memory_1_OMA_ACTIVE_pin 	: OUT std_logic;
		opb_external_memory_1_LEDS_DEBUG_pin 	: OUT std_logic_vector(0 to 15);
		opb_external_memory_1_OMA_BE_pin 		: OUT std_logic_vector(0 to 3)
		);
	END COMPONENT;


	
	COMPONENT pciCom
    Port ( 
		CLOCK			: IN 	STD_LOGIC;
		RESET			: IN 	STD_LOGIC;
		PCI_ADDS		: IN  	STD_LOGIC; 
		PCI_EMPTY 		: IN  	STD_LOGIC; 
		PCI_BUSY		: IN  	STD_LOGIC; 
		PCI_RW			: OUT  	STD_LOGIC; 
		PCI_RENWEN 		: OUT  	STD_LOGIC; 
		PCI_ADIO		: INOUT STD_LOGIC_VECTOR (0 to 31);	
--		LED_DEBUG	: OUT std_logic_vector(0 to 15);
		OMA_VALID 		: OUT 	STD_LOGIC;    
		OMA_DATA_I		: OUT 	STD_LOGIC_VECTOR(0 to 31);
		OMA_BE			: IN 	STD_LOGIC_VECTOR(0 to 3); 
		OMA_DATA_O		: IN 	STD_LOGIC_VECTOR(0 to 31);
		OMA_ADDRESS		: IN 	STD_LOGIC_VECTOR(0 to 31);
		OMA_RW			: IN 	STD_LOGIC;
		OMA_ACTIVE		: IN 	STD_LOGIC
		);
	END COMPONENT;
	
begin

	Inst_system: core PORT MAP(
		opb_external_memory_0_LEDS_DEBUG_pin 	=> fpga_0_LEDS_GPIO_d_out_pin,
		sys_clk_pin 							=> sys_clk_pin,
		sys_rst_pin 							=> rst_inv,
		opb_external_memory_0_OMA_DATA_O_pin 	=> CORE_DATA_O (0) ,
		opb_external_memory_0_OMA_DATA_I_pin 	=> CORE_DATA_I (0) ,
		opb_external_memory_0_OMA_VALID_pin 	=> CORE_VALID(0) ,
		opb_external_memory_0_OMA_ADDRESS_pin 	=> CORE_ADDRESS(0) ,
		opb_external_memory_0_OMA_RW_pin 		=> CORE_RW (0) ,
		opb_external_memory_0_OMA_ACTIVE_pin 	=> CORE_ACTIVE(0) ,
		opb_external_memory_0_OMA_BE_pin 		=> CORE_BE(0) ,
		opb_external_memory_1_OMA_DATA_O_pin 	=> CORE_DATA_O (1) ,
		opb_external_memory_1_OMA_DATA_I_pin 	=> CORE_DATA_I (1) ,
		opb_external_memory_1_OMA_VALID_pin 	=> CORE_VALID(1) ,
		opb_external_memory_1_OMA_ADDRESS_pin 	=> CORE_ADDRESS(1) ,
		opb_external_memory_1_OMA_RW_pin 		=> CORE_RW (1) ,
		opb_external_memory_1_OMA_ACTIVE_pin 	=> CORE_ACTIVE(1) ,
		opb_external_memory_1_OMA_BE_pin 		=> CORE_BE(1) 
	);

	arbiter: entity work.arbiter PORT MAP(
		CLOCK				=>  sys_clk_pin,
		RESET				=>  rst_inv,

		IN_OMA_DATA_O		=> CORE_DATA_O,
		IN_OMA_DATA_I		=> CORE_DATA_I,
		IN_OMA_VALID		=> CORE_VALID,
		IN_OMA_ADDRESS		=> CORE_ADDRESS,
		IN_OMA_RW			=> CORE_RW, 
		IN_OMA_ACTIVE		=> CORE_ACTIVE,
		IN_OMA_BE			=> CORE_BE,
		
		OUT_OMA_VALID		=> CACHE_VALID, 
		OUT_OMA_DATA_I		=> CACHE_DATA_I, 
		OUT_OMA_DATA_O		=> CACHE_DATA_O,
		OUT_OMA_ADDRESS		=> CACHE_ADDRESS,
		OUT_OMA_BE			=> CACHE_BE ,
		OUT_OMA_RW			=> CACHE_RW, 
		OUT_OMA_ACTIVE		=> CACHE_ACTIVE 
	
	);

	cache : entity work.cacheBlock PORT MAP (
		CLOCK           => sys_clk_pin,
        RESET           => rst_inv,
        -- From the arbiter to Cache
        IN_OMA_VALID    => CACHE_VALID,
        IN_OMA_DATA_I   => CACHE_DATA_I,
        IN_OMA_BE       => CACHE_BE,
        IN_OMA_DATA_O   => CACHE_DATA_O,
        IN_OMA_ADDRESS  => CACHE_ADDRESS,
        IN_OMA_RW       => CACHE_RW,
        IN_OMA_ACTIVE   => CACHE_ACTIVE,

        -- From the cache to comm.
        OUT_OMA_VALID   => OMA_VALID,
        OUT_OMA_DATA_I  => OMA_DATA_I,
        OUT_OMA_BE      => OMA_BE,
        OUT_OMA_DATA_O  => OMA_DATA_O,
        OUT_OMA_ADDRESS => OMA_ADDRESS,
        OUT_OMA_RW      => OMA_RW,
        OUT_OMA_ACTIVE  => OMA_ACTIVE
	);
	
	communication: pciCom PORT MAP(  
		CLOCK 		=> sys_clk_pin,
		RESET		=> rst_inv,
		PCI_ADDS	=> sPCI_ADDS, 
		PCI_EMPTY 	=> sPCI_EMPTY,
		PCI_BUSY	=> sPCI_BUSY,
		PCI_RW		=> sPCI_RW,
		PCI_RENWEN	=> sPCI_RENWEN,
		PCI_ADIO	=> PCI_ADIO,

		OMA_BE		=> OMA_BE,
		OMA_VALID 	=> OMA_VALID,
		OMA_DATA_I	=> OMA_DATA_I,
		OMA_DATA_O	=> OMA_DATA_O,
		OMA_ADDRESS	=> OMA_ADDRESS,
		OMA_RW		=> OMA_RW,
		OMA_ACTIVE	=> OMA_ACTIVE
		);
	
	IBUF_inst : IBUF
   generic map (
      IBUF_DELAY_VALUE => "0", 
      IFD_DELAY_VALUE => "AUTO", 
      IOSTANDARD => "DEFAULT")
   port map (
      O => rst_internal,  
      I => reset      
   );
		
	f: process(PCI_ADDS, PCI_EMPTY, PCI_BUSY, sPCI_RW, sPCI_RENWEN,rst_internal) is
	begin 
		sPCI_ADDS 	<= PCI_ADDS ; 
		sPCI_EMPTY 	<= PCI_EMPTY;
		sPCI_BUSY	<= PCI_BUSY;
		PCI_RW		<= sPCI_RW;
		PCI_RENWEN 	<= sPCI_RENWEN ;
		rst_inv		<= not rst_internal;
	end process;
			
end Behavioral;
