----------------------------------------------------------------------------------
-- Company: 
-- Engineer: 
-- 
-- Create Date:    17:14:16 11/10/2006 
-- Design Name: 
-- Module Name:    com - Behavioral 
-- Project Name: 
-- Target Devices: 
-- Tool versions: 
-- Description: 
--
-- Dependencies: 
--
-- Revision: 
-- Revision 0.01 - File Created
-- Additional Comments: 
--
----------------------------------------------------------------------------------
library IEEE;
use IEEE.STD_LOGIC_1164.ALL;
use IEEE.STD_LOGIC_ARITH.ALL;
use IEEE.STD_LOGIC_UNSIGNED.ALL;

---- Uncomment the following library declaration if instantiating
---- any Xilinx primitives in this code.
--library UNISIM;
--use UNISIM.VComponents.all;

entity pciCom is
    Port ( 
		--- PCI FPGA Spesific.
		CLOCK			: in std_logic;
		RESET			 : in std_logic;
			
		PCI_ADDS		: in  STD_LOGIC; -- ADIO is DATA when high, else Address.
		PCI_EMPTY 	: in  STD_LOGIC; -- Is empty
		PCI_BUSY		: in  STD_LOGIC; -- Can't write quite yet.
		PCI_RW		: out  STD_LOGIC; -- Will write to the PCI FPGA on high.
		PCI_RENWEN 	: out  STD_LOGIC; -- High disables communication.
		PCI_ADIO		: inout  STD_LOGIC_VECTOR (0 to 31);
		
		-- LED DEBUG..
		LED_DEBUG	: OUT std_logic_vector(0 to 15);

		--- Internal chat with the memory bus
		OMA_VALID 	: OUT std_logic;    
		OMA_DATA_I	: OUT std_logic_vector(0 to 31);
		OMA_DATA_O	: IN std_logic_vector(0 to 31);
		OMA_ADDRESS	: IN std_logic_vector(0 to 31);
		OMA_BE		: IN std_logic_vector(0 to 3);
		OMA_RW		: IN std_logic;
		OMA_ACTIVE	: IN std_logic
		);
end pciCom;

architecture Behavioral of pciCom is
	-- State machine variables. 
	type States is ( 	IDLE, 
							READ_START, READ_ADDR, READ_DATA, READ_IDLE,
							WRITE_START, WRITE_ADDR, WRITE_DATA,
							COMPLETE
						);
	
	-- constant signals to write out to the databus. 
	constant writeSignal : std_logic_vector(31 downto 0) :=(1 => '1', others => '0');
	constant readSignal : std_logic_vector(31 downto 0) := (0 => '1', others => '0');
	
	-- state signals
	constant sIDLE 		: std_logic_vector(0 to 15) := (0 => '0', others => '1');
	constant sREAD_START : std_logic_vector(0 to 15) := (1 => '0', others => '1');
	constant sREAD_ADDR	: std_logic_vector(0 to 15) := (2 => '0', others => '1');
	constant sREAD_DATA 	: std_logic_vector(0 to 15) := (3 => '0', others => '1');
	constant sREAD_IDLE	: std_logic_vector(0 to 15) := (4 => '0', others => '1');
	constant sWRITE_START : std_logic_vector(0 to 15):= (5 => '0', others => '1');
	constant sWRITE_ADDR	: std_logic_vector(0 to 15) := (6 => '0', others => '1');
	constant sWRITE_DATA	: std_logic_vector(0 to 15) := (7 => '0', others => '1');
	constant sCOMPLETE	: std_logic_vector(0 to 15) := (8 => '0', others => '1');
	
	signal state 	: States;
	signal data_o	: std_logic_vector(0 to 31) := (others => '1');
	signal data_i	: std_logic_vector(0 to 31) := (others => '1');
	signal address	: std_logic_vector(0 to 31) := (others => '1');
	
	signal clockCount	: std_logic_vector(0 to 31) := (others => '0');
	
begin

	countClock: process(CLOCK,RESET,state) is
	begin
		if rising_edge(CLOCK) then 
			if RESET = '1' or state = WRITE_START or state = READ_START then
				clockCount <= (others => '0');
			else 
				clockCount <= clockCount + 1;
			end if;
		end if; 
	end process; 

	fnord: process(CLOCK, RESET) is
	begin
		if RESET = '1' then
			PCI_RENWEN <= '1' ;
			state <= IDLE;
			
		elsif rising_edge(CLOCK) then
--			PCI_RENWEN <= '0'; -- Default to enable com.
--			OMA_VALID	<= '0'; -- NOT valid data per default.
			
			if PCI_EMPTY = '0' and state = READ_DATA then	
						-- Gather data from input. 
						data_i <= PCI_ADIO;
						-- Debug fnord.
						LED_DEBUG <= PCI_ADIO(0 to 15);
						OMA_VALID <= '1';
						state <= COMPLETE;
						
			elsif PCI_BUSY = '0'  then
			-- else
				OMA_VALID	<= '0'; -- NOT valid data per default.
				case state is  
					when IDLE =>
						PCI_RENWEN <= '1'; -- We're not enabling com when idle.
						PCI_ADIO <= ( others => 'Z' );
						
						-- Write on low!
						if OMA_RW = '0' and OMA_ACTIVE='1' then
							state <= WRITE_START;
							PCI_RENWEN <= '0';
						elsif OMA_RW = '1' and OMA_ACTIVE = '1' then 
							state <= READ_START;
							PCI_RENWEN <= '0';
						else
							state <= IDLE;
						end if;	
					
					-- Writing to the bus.
					when WRITE_START =>
						PCI_ADIO <= writeSignal;
						PCI_ADIO(16 to 19) <= OMA_BE;
						state <= WRITE_ADDR;
					when WRITE_ADDR =>
						PCI_ADIO <= address;
						state <= WRITE_DATA;	
					when WRITE_DATA =>
						PCI_ADIO <= data_o;
						-- Debug fnord
						OMA_VALID <= '1';
						state <= COMPLETE;
					
					-- Reading from the bus.
					when READ_START =>
						PCI_ADIO <= readSignal;
						state <= READ_ADDR;
					when READ_ADDR =>
						PCI_ADIO <= address;
						state <= READ_IDLE;
					when READ_IDLE =>
						PCI_ADIO <= (others => 'Z');
						state <= READ_DATA;
					
					
					-- The requested transaction is done!
					when COMPLETE =>
						PCI_ADIO <= data_i;
						state <= IDLE; 	
					when others =>
						null;
				end case;
			end if;
	end if;

	end process;
	
--	-- show state on led
--	lSate: process(state) is
--	begin
--		case state is
--			when IDLE =>
--				LED_DEBUG <= sIDLE;
--			when READ_START =>
--				LED_DEBUG <= sREAD_START;
--			when READ_ADDR =>
--				LED_DEBUG <= sREAD_ADDR ;
--			when READ_DATA =>
--				LED_DEBUG <= sREAD_DATA;
--			when READ_IDLE =>
--				LED_DEBUG <= sREAD_IDLE ;
--			when WRITE_START =>
--				LED_DEBUG <= sWRITE_START;
--			when WRITE_ADDR=>
--				LED_DEBUG <= sWRITE_ADDR;
--			when WRITE_DATA=>
--				LED_DEBUG <= sWRITE_DATA;
--			when COMPLETE=>
--				LED_DEBUG <= sCOMPLETE;
--		end case;
--	end process;
	
	comb: process(state, OMA_DATA_O, OMA_ADDRESS, RESET,data_i) is
	begin 
		
		
		if RESET = '1' then
			data_o <= (others => 'Z');
			address <= (others => 'Z');
		else
			PCI_RW		<= '1'; -- We're writing as default
			--OMA_VALID	<= '0';
			
			OMA_DATA_I <= data_i;
			address <= OMA_ADDRESS;
			data_o <= OMA_DATA_O;
			
			case state is					
				when READ_DATA => 
					PCI_RW <= '0'; -- READ !!			
				when COMPLETE => 
					-- OMA_VALID <= '1';
					null;
				when others =>
					null;
			end case;
	end if; 
	end process;
		
end Behavioral;

