----------------------------------------------------------------------------------
-- Create Date:    13:58:29 11/20/2006 
-- Design Name: 
-- Module Name:    toplevel - Behavioral 
-- Project Name: 
-- Target Devices: 
-- Tool versions: 
-- Description: 
--
-- Dependencies: 
--
-- Revision: 
-- Revision 0.01 - File Created
-- Additional Comments: 
--
----------------------------------------------------------------------------------
library IEEE;
use IEEE.STD_LOGIC_1164.ALL;
use IEEE.STD_LOGIC_ARITH.ALL;
use IEEE.STD_LOGIC_UNSIGNED.ALL;

---- Uncomment the following library declaration if instantiating
---- any Xilinx primitives in this code.
library UNISIM;
use UNISIM.VComponents.all;

entity toplevel is
	PORT(
		sys_clk_pin : IN std_logic;
		reset : IN std_logic;
		fpga_0_LEDS_GPIO_d_out_pin : OUT std_logic_vector(0 to 15);
		PCI_ADDS		: in  STD_LOGIC; 
		PCI_EMPTY 	: in  STD_LOGIC; 
		PCI_BUSY		: in  STD_LOGIC; 
		PCI_RW		: out  STD_LOGIC; 
		PCI_RENWEN 	: out  STD_LOGIC; 
		PCI_ADIO		: inout  STD_LOGIC_VECTOR (0 to 31));
end toplevel;

architecture Behavioral of toplevel is
		signal OMA_VALID 	: std_logic;    
		signal OMA_DATA_I	: std_logic_vector(0 to 31) := (others =>'0');
		signal OMA_DATA_O	: std_logic_vector(0 to 31) := (others =>'0');
		signal OMA_ADDRESS	: std_logic_vector(0 to 31) := x"DEADBEEF";
		signal OMA_RW		: std_logic;
		signal OMA_ACTIVE	: std_logic;
		signal OMA_BE		: std_logic_vector (0 to 3) := (others => '0');
		
		
		signal sPCI_ADDS	: std_logic := '0';
		signal sPCI_EMPTY 	: std_logic := '0';
		signal sPCI_BUSY	: std_logic := '0';
		signal sPCI_RW 		: std_logic := '0';
		signal sPCI_RENWEN 	: std_logic := '1';
		
		signal rst_inv 		: std_logic;
		signal rst_internal : std_logic;
		
		
	COMPONENT system
	PORT(
		opb_external_memory_0_LEDS_DEBUG_pin : OUT std_logic_vector(0 to 15);
		sys_clk_pin : IN std_logic;
		sys_rst_pin : IN std_logic;
		opb_external_memory_0_OMA_DATA_I_pin : IN std_logic_vector(0 to 31);
		opb_external_memory_0_OMA_VALID_pin : IN std_logic;          
		opb_external_memory_0_OMA_DATA_O_pin : OUT std_logic_vector(0 to 31);
		opb_external_memory_0_OMA_ADDRESS_pin : OUT std_logic_vector(0 to 31);
		opb_external_memory_0_OMA_RW_pin : OUT std_logic;
		opb_external_memory_0_OMA_BE_pin : OUT std_logic_vector(0 to 3);
		opb_external_memory_0_OMA_ACTIVE_pin : OUT std_logic
		);
	END COMPONENT;
	
	COMPONENT pciCom
    Port ( 
		CLOCK			: in std_logic;
		RESET			: in std_logic;
		PCI_ADDS		: in  STD_LOGIC; 
		PCI_EMPTY 	: in  STD_LOGIC; 
		PCI_BUSY		: in  STD_LOGIC; 
		PCI_RW		: out  STD_LOGIC; 
		PCI_RENWEN 	: out  STD_LOGIC; 
		PCI_ADIO		: inout  STD_LOGIC_VECTOR (0 to 31);	
--		LED_DEBUG	: OUT std_logic_vector(0 to 15);
		OMA_VALID 	: OUT std_logic;    
		OMA_DATA_I	: OUT std_logic_vector(0 to 31);
		OMA_BE		: IN std_logic_vector(0 to 3); 
		OMA_DATA_O	: IN std_logic_vector(0 to 31);
		OMA_ADDRESS	: IN std_logic_vector(0 to 31);
		OMA_RW		: IN std_logic;
		OMA_ACTIVE	: IN std_logic
		);
	END COMPONENT;
	
begin

	Inst_system: system PORT MAP(
		opb_external_memory_0_LEDS_DEBUG_pin 	=> fpga_0_LEDS_GPIO_d_out_pin,
		sys_clk_pin 							=> sys_clk_pin,
		sys_rst_pin 							=> rst_inv,
		opb_external_memory_0_OMA_DATA_O_pin 	=> OMA_DATA_O ,
		opb_external_memory_0_OMA_DATA_I_pin 	=> OMA_DATA_I ,
		opb_external_memory_0_OMA_VALID_pin 	=> OMA_VALID,
		opb_external_memory_0_OMA_ADDRESS_pin	=> OMA_ADDRESS,
		opb_external_memory_0_OMA_RW_pin 		=> OMA_RW ,
		opb_external_memory_0_OMA_ACTIVE_pin 	=> OMA_ACTIVE,
		opb_external_memory_0_OMA_BE_pin 		=> OMA_BE
	);
	
	communication: pciCom PORT MAP(  
		CLOCK 		=> sys_clk_pin,
		RESET		=> rst_inv,
		PCI_ADDS	=> sPCI_ADDS, 
		PCI_EMPTY 	=> sPCI_EMPTY,
		PCI_BUSY	=> sPCI_BUSY,
		PCI_RW		=> sPCI_RW,
		PCI_RENWEN	=> sPCI_RENWEN,
		PCI_ADIO	=> PCI_ADIO,
		OMA_BE		=> OMA_BE,
		OMA_VALID 	=> OMA_VALID,
		OMA_DATA_I	=> OMA_DATA_I,
		OMA_DATA_O	=> OMA_DATA_O,
		OMA_ADDRESS	=> OMA_ADDRESS,
		OMA_RW		=> OMA_RW,
		OMA_ACTIVE	=> OMA_ACTIVE
		);
	
	IBUF_inst : IBUF
	   generic map (
		  IBUF_DELAY_VALUE => "0", 
		  IFD_DELAY_VALUE => "AUTO", 
		  IOSTANDARD => "DEFAULT")
	   port map (
		  O => rst_internal,     
		  I => reset      
	   );
		
	f: process(PCI_ADDS, PCI_EMPTY, PCI_BUSY, sPCI_RW, sPCI_RENWEN,rst_internal) is
	begin 
		sPCI_ADDS 	<= PCI_ADDS ; 
		sPCI_EMPTY 	<= PCI_EMPTY;
		sPCI_BUSY	<= PCI_BUSY;
		PCI_RW		<= sPCI_RW;
		PCI_RENWEN 	<= sPCI_RENWEN ;
		rst_inv		<= not rst_internal;
	end process;
			
end Behavioral;

