#include "cpu.h"
#include "util.h"

#include <stdio.h>

int openCard(int cardNum, char *bitfile){
	char error[1024];
	DWORD errorNum;

	cpu.locate = NULL;
	cpu.card = NULL;
	cpu.dma = NULL;
	cpu.send = NULL;
	cpu.recv = NULL;
	
	cpu.locate = DIME_LocateCard(dlPCI,
				mbtALL,
				NULL,
				dldrDEFAULT,
				dlDEFAULT);

	if( !cpu.locate ){
		DIME_GetError(NULL,&errorNum,error);
		printf("\nLocate Error #%d\n%s\n",errorNum,error);
		closeCard();
		return -1;
	}

	if(!( cpu.card = DIME_OpenCard(cpu.locate,
					cardNum,dccOPEN_DEFAULT))) 
	{
		DIME_GetError(NULL,&errorNum,error);
		printf("\nCard Error #%d\n%s\n",errorNum,error);
		closeCard();
		return -2;
	}

	// Setup chat.
	if( setupDMA() < 1 ) {
		printf("DMA failed\n");
		closeCard();
		return -3;
	}

	if( DIME_JTAGControl(cpu.card, djtagCONFIGSPEED,djtagMAXSPEED100) ) {
		printf("JTAG died\n");
		DIME_GetError(NULL,&errorNum,error);
		printf("\nError #%d\n%s\n",errorNum,error);
		closeCard();
		return -4;
	}

	// Finally set the clock before configuring the card:
	DIME_SetOscillatorFrequency (cpu.card, CLOCK_NUM, CLOCK_FREQ, NULL);

	if(configureCard(bitfile) < 1){
		
		printf("Could not configure FPGA\n");
		closeCard();
		return -5;
	}

	if( resetCard() < 1 ){
		printf("Error resetting card.\n");
		closeCard();
		return -6;
	};
	
	return 1;
}

int setupDMA(){
	char error[1024];
	DWORD errorNum;

	bzero(cpu.recvBuffer,sizeof(int)*BUFFER_SIZE);
	bzero(cpu.sendBuffer,sizeof(int)*BUFFER_SIZE);

	if( !cpu.locate || ! cpu.card )
		return -1;

	if( !( cpu.send = DIME_LockMemory(cpu.card,
						(DWORD*)cpu.sendBuffer,
						sizeof(cpu.sendBuffer))))
	{
		printf("Could not setup send buffer\n");	
		return -2;		
	}

	if( !( cpu.recv = DIME_LockMemory(cpu.card,
						(DWORD*)cpu.recvBuffer,
						sizeof(cpu.recvBuffer))))
	{
		if( cpu.send ) DIME_UnLockMemory(cpu.card, cpu.send);
		printf("Could not setup send buffer\n");	
		return -3;		
	}

	if(! (  cpu.dma = DIME_DMAOpen(cpu.card, 1,0) ) ) {
		if( cpu.send ) DIME_UnLockMemory(cpu.card, cpu.send);
		if( cpu.recv ) DIME_UnLockMemory(cpu.card, cpu.recv);

		printf("Error opening DMA Channel numero uno\n");

		return -4;
	}

	// DO NOT INCREASE THE LOCAL MEMORY ADDR AFTER USE!!
	DIME_DMAControl(cpu.card, cpu.dma,ddmaLOCALNOINC,0);

	return 1;
}

int configureCard(char *bitfile){
	char error[1024];
	DWORD errorNum;

	if( !bitfile || !cpu.card )
			return -1;

	if( !DIME_BootVirtexSingle(cpu.card, bitfile) ) {
	 	DIME_GetError(NULL,&errorNum,error);
	 	printf("Configure Error #%d\n%s\n",errorNum,error);
	}

	return 1;
}

int resetCard(){
	// ENABLE = 0, DISABLE = 1 
	DIME_CardResetControl(cpu.card, drONBOARDFPGA, drENABLE, 0);
	DIME_CardResetControl(cpu.card, drINTERFACE, drTOGGLE, 0);
	DIME_CardResetControl(cpu.card, drONBOARDFPGA, drDISABLE, 0);
	
	return 1;
}

int closeCard(){
	if( cpu.card) {
		if( cpu.send ) DIME_UnLockMemory(cpu.card, cpu.send);
		if( cpu.recv ) DIME_UnLockMemory(cpu.card, cpu.recv);
		if( cpu.dma ) DIME_DMAClose(cpu.card, cpu.dma,ddmaCLOSETERMINATE);

		DIME_CloseCard(cpu.card); }

	// Close down the card
	if( cpu.locate ) DIME_CloseLocate(cpu.locate);

	cpu.card = (cpu.locate = NULL);

	return 1;
}

int writeCard(int size) {
	if( !cpu.card )	return -1; 
	if( !cpu.dma ) 	return -2; 
	if( !cpu.send ) return -3; 


	if( ddmaOK !=
	    DIME_DMAWriteFromLockedMem(cpu.card, cpu.dma,
		    	cpu.send, 0, 1, ddmaBLOCKING) ) 
	{
		printf("Error writing stuff..!");
	}

	return 1;
}

int readCard(int size){
	if( !cpu.card ) return -1; 
	if( !cpu.dma ) return -2; 
	if( !cpu.recv ) return -3;
		
	bzero(cpu.recvBuffer,BUFFER_SIZE);
	
	if ( ddmaOK != DIME_DMAReadToLockedMem(cpu.card, 
				cpu.dma, cpu.recv,
				0, size, ddmaBLOCKING ) ) {
		printf("Error reading stuff\n");
	}

	return size;
}

// User functions.
unsigned int getWord32(){
	readCard(1);
	return cpu.recvBuffer[0];
}

unsigned int writeWord32(unsigned int word){
	cpu.sendBuffer[0] = HostToCoreI(word);
	writeCard(1);
	return 1;
}
