/**
 * Simple memory holder.. 
 * Implementing a array, 
 * A hash isn't worth the implementation 
 * time, and I don't want to allocate 4Gb 
 * of data for a traditional array.
 *
 * Kenneth Oestby <kenneo@idi.ntnu.no>
 */

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <unistd.h>

#include "memory.h"
#include "util.h"
#include "rb.h"

int mem_load(Memory *m, char *filename){
	FILE *f = NULL;
	int memLoc = 0;
	unsigned int *data = 0;
	data =(unsigned int*)malloc(sizeof(unsigned int));
	*data = 0;

	if ( !m || !filename ) return -1;

	if( ! ( f= fopen(filename,"r") )) {
		return -2;
	}

	while( fread((void*)data, sizeof(unsigned char),
	 	1, f)) {
	  mem_writeByte(memLoc++, reverseInt8(*data),m);
	}

	free(data);
	
	return memLoc;
}

int mem_print(Memory *m){
	if ( ! m  || !m->data) return -1;
	
	int i = 0;
	int x ; 
	for( i = 0 ; i < MEM_SIZE; i++ ) {
		if ( !(i % 32) ) 
			printf("\n %03X ", i );

		printf("%02hhX ", mem_read(i, &x, m) );
	}
}

int mem_clean(Memory *m){
	return 1;
}

/*
 * Zero out the memory from the given offset. 
 */
int mem_zero(Memory *m, unsigned int offset){
	if ( !m ) return -1; 

	bzero(m->data + offset, (m->mem_size - offset) * sizeof(MemBlock));
	return 1;
}

Memory *mem_init(){
	Memory *m 	= NULL;
	m = (Memory*)malloc(sizeof(Memory));
	m->data 	= NULL;
	m->mem_size 	= 0;
	m->mem_used 	= 0;
	m->max_addr 	= 0;

	/*
	 * Bite of some bits of memory.. 
	 * 
	 * If you're going use the CPU, 
	 * you're probably going to want 
	 * some memory to go along in the 
	 * first place. Malloc is _slow_!
	 * Default is 20.. 20 * 32 should be enough
	 * for everybody.
	 */

	if ( ! ( m->data = (MemBlock*)malloc(sizeof(MemBlock) * START_MEM) ) ) {
		mem_clean(m);
		return NULL;
	}

	// m->table = rb_create(compare_ints,NULL,NULL);

	m->bytes = (unsigned char*)malloc(MEM_SIZE * sizeof(char));
	
	m->mem_size = START_MEM;
	mem_zero(m, 0);
	return m;
}

unsigned int mem_read(unsigned int addr,int *error,Memory *m){
	if ( !m ){
		if (error) *error = -1;
	}/*else if( !m->mem_used ){ 
		if (error) *error = -2;
	}else if( addr > m->max_addr ) {
		if (error) *error = -3;
	}*/

	if ( error && *error < 0 ) return 0;

	/*
	int i = 0, j = 0; 
	MemBlock *tmp = NULL;
	unsigned int returnMe = 0; 

	for ( i = 0; i < m->mem_used; i++ ) {
		if ( m->data[i].addr == addr ){
			tmp = m->data + i;
			do {
				printf("Fnord:%p\n",tmp);
				printf("Next:%p\n",tmp->next);
				returnMe |= tmp->data << j * 8;
			}while( (tmp = tmp->next) && ++j < 4 ) ;
		}
	}

	return returnMe;
	*/

	return m->bytes[addr+3] << 24  | m->bytes[addr+2] << 16 | m->bytes[addr+1] << 8 | m->bytes[addr];
//	return m->bytes[addr];
}

int updatePointers(Memory *m, unsigned int addr){
	if ( !m ) return -1;

	// Slow implementation on write to help speed up read.
	// Update the next and prev-pointer.
	int i = 0 ;
	for(i = 0; i<m->mem_used;i++){
		if( m->data[i].addr == addr -1 )
			m->data[i].next = m->data + m->mem_used -1;
		else if( m->data[i].addr == addr +1 )
			m->data[i].prev = m->data + m->mem_used -1;
	}

	return 1; 
}

unsigned int mem_writeByte(unsigned int addr, unsigned char data, Memory *m){
	if( !m ) return 0; 
	static int i = 0; 

	/*
	// Go through the array of memory to find the memory block.
	// Future implementation would need a hash or something
	// faster..
	for ( i = 0; i < m->mem_used; i++ ) {
		if ( m->data[i].addr == addr ){
			m->data[i].data = data;
			return 1; 
		}
	}

	if ( m->max_addr < addr )
		m->max_addr = addr; 

	// If not found in the array.. Expand it.. 
	if ( m->mem_used < m->mem_size ) {
		m->data[m->mem_used].addr = addr;
		m->data[m->mem_used++].data = data;
	}else {
		// We need to grow the actual data array.
		m->mem_size += GROW_RATE;
		printf("Now growing to %d\n",m->mem_size);
		m->data = (MemBlock*)realloc((void*)m->data,m->mem_size*sizeof(MemBlock));

		m->data[m->mem_used].addr = addr;
		m->data[m->mem_used++].data = data;
	}

	updatePointers(m,addr);
	*/

	m->bytes[addr] = data;

	return 1;
}

unsigned int mem_write(unsigned int addr, unsigned int data, unsigned char byteEnabled, Memory *m){
	int i = 0 ;
	char d;

	// Split up the data in based upon byteEnabled field!
	for(i = 0; i<3; i++){
		if ( byteEnabled & ( 1 << i ) ){
			d = (data >> sizeof(char) * 4) & 0xFF;
			mem_writeByte(addr+i, d, m);
		}else break; 
	}

	return 1; 
}
